<?php
/**
 * CirrusShield REST client
 */
class Cirrus {
    public $username;
    public $password;
    public $base_url;
    public $curl_opts = array();
    public function __construct($base_url, $username, $password) {
        if (!function_exists('curl_init')) {
            throw new Exception('Cirrus requires CURL module');
        }
        $this->base_url = $base_url;
        $this->username = $username;
        $this->password = $password;
    }

    function console_log($output, $with_script_tags = true) {
        $js_code = 'console.log(' . json_encode($output, JSON_HEX_TAG) .');';
        if ($with_script_tags) {
            $js_code = '<script>' . $js_code . '</script>';
        }
        echo $js_code;
    }

    /**
     * Do CURL request with authorization
     */
    private function do_request($resource, $method, $input) {
        $called_url = $this->base_url . "/" . $resource;
        $ssl_verify = true;
        if (strtoupper(substr(PHP_OS, 0, 3)) === 'WIN') {
            // Windows only over-ride
            $ssl_verify = false;
        }
        $args = array(
            'method' => $method,
            'sslverify' => $ssl_verify,
            'headers' => array(
//            'api-key' => $this->api_key,
                'Content-Type' => 'application/json'),
        );
        $args['body'] = $input;
        $response = wp_remote_request($called_url, $args);
        
        $data = wp_remote_retrieve_body($response);
        return json_decode($data, true);
    }
    public function get($resource, $input) {
        return $this->do_request($resource, "GET", $input);
    }
    public function put($resource, $input) {
        return $this->do_request($resource, "PUT", json_encode($input));
    }
    public function post($resource, $input) {
        return $this->do_request($resource, "POST", json_encode($input));
    }
    public function delete($resource, $input) {
        return $this->do_request($resource, "DELETE", $input);
    }
    
    /**
     * Do CURL request with authorization
     */
    private function do_request1($resource, $method, $input) {
         $called_url = $this->base_url . "/" . $resource;
        $ssl_verify = true;
        if (strtoupper(substr(PHP_OS, 0, 3)) === 'WIN') {
            // Windows only over-ride
            $ssl_verify = false;
        }
        $args = array(
            'method' => $method,
            'sslverify' => $ssl_verify,
            'headers' => array(
//            'api-key' => $this->api_key,
                'Content-Type' => 'application/json'),
        );
        $args['body'] = $input;
         
        $response = wp_remote_request($called_url, $args);
        if(strtolower($method)=='post'){
          
          // echo '<pre>';
          //   print_r($response);
          // echo '</pre>';  
          // exit;
          
            $response  =  $this->response_filter_in_xml($response['body']);
            
            return  $response;
         
        }
        $data = wp_remote_retrieve_body($response);
        return json_decode($data, true);
        //return var_export($response,true); this sends back the full response body - used for debugging
    }
    
   public function response_filter_in_xml($resBody){
         $xmlRes = simplexml_load_string($resBody);
         $array  = json_decode(json_encode($xmlRes), true); 
         $model  = array_keys($array)[0];
         if(strtolower($xmlRes->{$model}->Success)=='false'){
                $errorMessage = trim($xmlRes->{$model}->ErrorMessage);
                 /*
                 $errorContent = '';
                foreach (explode(',',$errorMessage) as $key => $value) {
                       if(''!=$value){
                           $errorContent .= $value;
                         
                           $fieldError = explode(':',$value); 
                           if(count($fieldError) > 1){
                             $errorContent .= $fieldError[0].': '.$this->api_cirrus_shield_errorMessage($fieldError[1]).'<br/>';
                           }else{
                            $errorContent .= $this->api_cirrus_shield_errorMessage($value).'<br/>';
                           }
                           
                           
                       }
                 }
                 */
                $responseReturn['code']        = '404';
                $responseReturn['errMessage']  = $errorMessage;
              }else{
                $responseReturn['code']     = '200';
                $responseReturn['guid']     = strval($xmlRes->{$model}->GUID);
              }
       return $responseReturn;
   }
  
  public function api_cirrus_shield_errorMessage($erroCode){
         $defineError['Error_MSG_Field_Required']                = 'requiredMsg';
         $defineError['Error_MSG_Value_entered_not_valid_email'] = 'invalidMsg';
         $defineError['Error_MSG_Value_Must_Be_Unique']          = 'existMsg';
           if(array_key_exists($erroCode,$defineError)){
              return $defineError[$erroCode];
              }
            else{
              return $erroCode;
            }
         
  }
    public function get1($resource, $input) {
        return $this->do_request1($resource, "GET", $input);
    }
    public function put1($resource, $input) {
        return $this->do_request1($resource, "PUT", json_encode($input));
    }
    public function post1($resource, $input) {
        return $this->do_request1($resource, "POST", json_encode($input));
    }
    public function delete1($resource, $input) {
        return $this->do_request1($resource, "DELETE", $input);
    }
    
    /*
     * */
    public function get_access_tokens() {
        return $this->get1("AuthToken?Username=" . $this->username . "&password=" . $this->password, "");
    }
    public function get_modules($access_token) {
        return $this->get1("DescribeAll?authToken=" . $access_token, "");
    }
    public function get_module($module, $access_token) {
        return $this->get1("Describe/" . $module . "?authToken=" . $access_token, "");
    }
    public function data_action($module, $data, $access_token) {
        return $this->post1("DataAction/" . $module . "?authToken=" . $access_token . "&action=insert&matchingFieldName=id", $data);
    }
  public function update_data_action($module, $data, $access_token,$matchFN) {
        return $this->post1("DataAction/" . $module . "?authToken=" . $access_token . "&action=update&matchingFieldName=id", $data);
    }
   
  public function upload_file_action($urlParams,$array){
     
       $url = sprintf("%s?%s", $this->base_url."/UploadFile", http_build_query($urlParams));
                            $headers = array(
                                             "Accept: application/json",
                                            );
                            
                            $client = curl_init();
                            curl_setopt($client, CURLOPT_RETURNTRANSFER, true);
                            curl_setopt($client, CURLOPT_URL, $url);
                            curl_setopt($client, CURLOPT_HTTPHEADER, $headers);
                            curl_setopt($client, CURLOPT_POSTFIELDS, "=".json_encode($array));
                            curl_setopt($client, CURLOPT_POST, true);
                            curl_setopt($client, CURLINFO_HEADER_OUT, true);
                            curl_setopt($client, CURLOPT_SSLVERSION, 6);
                            $response = curl_exec($client);
                            return $response;
  }
    /*
      Get Account.
      No input required
     */
    public function get_account() {
        return array();
        return $this->get("account", "");
    }
    /*
      Get SMTP details.
      No input required
     */
    public function get_smtp_details() {
        return array();
        return $this->get("account/smtpdetail", "");
    }
    /*
      Get a particular campaign detail.
      @param {Array} data contains php array with key value pair.
      @options data {Integer} id: Unique Id of the campaign [Mandatory]
     */
    public function get_campaign_v2($data) {
        return array();
        return $this->get("campaign/" . $data['id'] . "/detailsv2", "");
    }
    /*
      Get all campaigns detail.
      @param {Array} data contains php array with key value pair.
      @options data {String} type: Type of campaign. Possible values – classic, trigger, sms, template ( case sensitive ) [Optional]
      @options data {String} status: Status of campaign. Possible values – draft, sent, archive, queued, suspended, in_process, temp_active, temp_inactive ( case sensitive ) [Optional]
      @options data {Integer} page: Maximum number of records per request is 500, if there are more than 500 campaigns then you can use this parameter to get next 500 results [Optional]
      @options data {Integer} page_limit: This should be a valid number between 1-500 [Optional]
     */
    public function get_campaigns_v2($data) {
        return array();
        return $this->get("campaign/detailsv2", $data);
    }
    /*
      Get all lists detail.
      @param {Array} data contains php array with key value pair.
      @options data {Integer} list_parent: This is the existing folder id & can be used to get all lists belonging to it [Optional]
      @options data {Integer} page: Maximum number of records per request is 50, if there are more than 50 processes then you can use this parameter to get next 50 results [Mandatory]
      @options data {Integer} page_limit: This should be a valid number between 1-50 [Mandatory]
     */
    public function get_lists($data) {
        return array();
        return $this->get("list", $data);
    }
    /*
      Get a particular list detail.
      @param {Array} data contains php array with key value pair.
      @options data {Integer} id: Id of list to get details [Mandatory]
     */
    public function get_list($data) {
        return array();
        return $this->get("list/" . $data['id'], "");
    }
    /*
      Create a new list.
      @param {Array} data contains php array with key value pair.
      @options data {String} list_name: Desired name of the list to be created [Mandatory]
      @options data {Integer} list_parent: Folder ID [Mandatory]
     */
    public function create_list($data) {
        return array();
        return $this->post("list", $data);
    }
    /*
      Display details of all users for the given lists.
      @param {Array} data contains php array with key value pair.
      @options data {Array} listids: These are the list ids to get their data. The ids found will display records [Mandatory]
      @options data {String} timestamp: This is date-time filter to fetch modified user records >= this time. Valid format Y-m-d H:i:s. Example: "2015-05-22 14:30:00" [Optional]
      @options data {Integer} page: Maximum number of records per request is 500, if in your list there are more than 500 users then you can use this parameter to get next 500 results [Optional]
      @options data {Integer} page_limit: This should be a valid number between 1-500 [Optional]
     */
    public function display_list_users($data) {
        return array();
        return $this->post("list/display", $data);
    }
    /*
      Access all the attributes information under the account.
      No input required
     */
    public function get_attributes() {
        return array();
        return $this->get("attribute", "");
    }
    /*
      Access the specific type of attribute information.
      @param {Array} data contains php array with key value pair.
      @options data {String} type: Type of attribute. Possible values – normal, transactional, category, calculated & global [Optional]
     */
    public function get_attribute($data) {
        return array();
        return $this->get("attribute/" . $data['type'], "");
    }
    /*
      Create an Attribute.
      @param {Array} data contains php array with key value pair.
      @options data {String} type: Type of attribute. Possible values – normal, transactional, category, calculated & global ( case sensitive ) [Mandatory]
      @options data {Array} data: The name and data type of ‘normal’ & ‘transactional’ attribute to be created in your CirrusShield account. It should be sent as an associative array. Example: array(‘ATTRIBUTE_NAME1′ => ‘DATA_TYPE1′, ‘ATTRIBUTE_NAME2’=> ‘DATA_TYPE2′).
      The name and data value of ‘category’, ‘calculated’ & ‘global’, should be sent as JSON string. Example: ‘[{ "name":"ATTRIBUTE_NAME1", "value":"Attribute_value1" }, { "name":"ATTRIBUTE_NAME2", "value":"Attribute_value2" }]’. You can use commas to separate multiple attributes [Mandatory]
     */
    public function create_attribute($data) {
        return array();
        return $this->post("attribute/", $data);
    }
    /*
      Get Access a specific user Information.
      @param {Array} data contains php array with key value pair.
      @options data {String} email: Email address of the already existing user in the CirrusShield contacts [Mandatory]
     */
    public function get_user($data) {
        return array();
        return $this->get("user/" . $data['email'], "");
    }
    /*
      Import Users Information.
      @param {Array} data contains php array with key value pair.
      @options data {String} url: The URL of the file to be imported. Possible file types – .txt, .csv [Mandatory: if body is empty]
      @options data {String} body: The Body with csv content to be imported. Example: ‘NAME;SURNAME;EMAIL\n"Name1";"Surname1";"example1@example.net"\n"Name2";"Surname2";"example2@example.net"‘, where \n separates each user data. You can use semicolon to separate multiple attributes [Mandatory: if url is empty]
      @options data {Array} listids: These are the list ids in which the the users will be imported [Mandatory: if name is empty]
      @options data {String} notify_url: URL that will be called once the import process is finished [Optional] In notify_url, we are sending the content using POST method
      @options data {String} name: This is new list name which will be created first & then users will be imported in it [Mandatory: if listids is empty]
      @options data {Integer} list_parent: This is the existing folder id & can be used with name parameter to make newly created list’s desired parent [Optional]
     */
    public function import_users($data) {
        return array();
        return $this->post("user/import", $data);
    }
    /*
      Get Access of created senders information.
      @param {Array} data contains php array with key value pair.
      @options data {String} option: Options to get senders. Possible options – IP-wise, & Domain-wise ( only for dedicated IP clients ). Example: to get senders with specific IP, use $option=’1.2.3.4′, to get senders with specific domain use, $option=’domain.com’, & to get all senders, use $option="" [Optional]
     */
    public function get_senders($data) {
        return array();
        return $this->get("advanced", $data);
    }
    /*
      Send Transactional Email.
      @param {Array} data contains php array with key value pair.
      @options data {Array} to: Email address of the recipient(s). It should be sent as an associative array. Example: array("to@example.net"=>"to whom"). You can use commas to separate multiple recipients [Mandatory]
      @options data {String} subject: Message subject [Mandatory]
      @options data {Array} from Email address for From header. It should be sent as an array. Example: array("from@email.com","from email") [Mandatory]
      @options data {String} html: Body of the message. (HTML version) [Mandatory]. To send inline images, use <img src="{YourFileName.Extension}" alt="image" border="0" >, the 'src' attribute value inside {} (curly braces) should be same as the filename used in 'inline_image' parameter
      @options data {String} text: Body of the message. (text version) [Optional]
      @options data {Array} cc: Same as to but for Cc. Example: array("cc@example.net","cc whom") [Optional]
      @options data {Array} bcc: Same as to but for Bcc. Example: array("bcc@example.net","bcc whom") [Optional]
      @options data {Array} replyto: Same as from but for Reply To. Example: array("from@email.com","from email") [Optional]
      @options data {Array} attachment: Provide the absolute url of the attachment/s. Possible extension values = gif, png, bmp, cgm, jpg, jpeg, txt, css, shtml, html, htm, csv, zip, pdf, xml, doc, xls, ppt, tar, and ez. To send attachment/s generated on the fly you have to pass your attachment/s filename & its base64 encoded chunk data as an associative array. Example: array("YourFileName.Extension"=>"Base64EncodedChunkData"). You can use commas to separate multiple attachments [Optional]
      @options data {Array} headers: The headers will be sent along with the mail headers in original email. Example: array("Content-Type"=>"text/html; charset=iso-8859-1"). You can use commas to separate multiple headers [Optional]
      @options data {Array} inline_image: Pass your inline image/s filename & its base64 encoded chunk data as an associative array. Example: array("YourFileName.Extension"=>"Base64EncodedChunkData"). You can use commas to separate multiple inline images [Optional]
     */
    public function send_email($data) {
        return array();
        return $this->post("email", $data);
    }
    /*
      Send templates created on CirrusShield, through CirrusShield SMTP (transactional mails).
      @param {Array} data contains php array with key value pair.
      @options data {Integer} id: Id of the template created on CirrusShield account [Mandatory]
      @options data {String} to: Email address of the recipient(s). You can use pipe ( | ) to separate multiple recipients. Example: "to-example@example.net|to2-example@example.net" [Mandatory]
      @options data {String} cc: Same as to but for Cc [Optional]
      @options data {String} bcc: Same as to but for Bcc [Optional]
      @options data {Array} attrv The name of attribute present in your CirrusShield account. It should be sent as an associative array. Example: array("NAME"=>"name"). You can use commas to separate multiple attributes [Optional]
      @options data {String} attachment_url: Provide the absolute url of the attachment. Url not allowed from local machine. File must be hosted somewhere [Optional]
      @options data {Array} attachment: To send attachment/s generated on the fly you have to pass your attachment/s filename & its base64 encoded chunk data as an associative array [Optional]
     */
    public function send_transactional_template($data) {
        return array();
        $id = $data['id'];
        unset($data['id']);
        return $this->put("template/" . $id, $data);
    }

   
    public function delete_token($key) {
        return array();
        return $this->post("account/deletetoken", json_encode(array("token" => $key)));
    }
}
?>