<?php

/**
 * Admin page : dashboard
 *
 * @package CS_Page_Form
 */
//require_once( 'wp-config.php' ); 
//require_once( 'wp-includes/wp-db.php' ); 
if (!class_exists('CS_Page_Form')) {
    /**
     * Page class that handles backend page <i>dashboard ( for admin )</i> with form generation and processing
     *
     * @package CS_Page_Form
     */
    class CS_Page_Form
    {
        /** Page slug */
        const PAGE_ID = 'cspage_form';
        /**
         * Page hook
         *
         * @var false|string
         */
        protected $page_hook;
        /**
         * Page tabs
         *
         * @var mixed
         */
        protected $tabs;
        /**
         * Form ID
         *
         * @var string
         */
        public $formID;
        /**
         * Default compliant Note
         *
         * @var string
         */
        public $defaultComplianceNote;
        /**
         * Constructs new page object and adds entry to WordPress admin menu
         */
        function __construct()
        {
            $title = get_bloginfo('name');
            $this->defaultComplianceNote = sprintf(esc_attr('Your e-mail address is only used to send you our newsletter and information about the activities of %s. You can always use the unsubscribe link included in the newsletter.', 'cslang'), $title);
            if (CS_Manager::is_done_validation() == TRUE) {
                add_menu_page(__('Cirrus Shield', 'cslang'), __('Cirrus Shield', 'cslang'), 'manage_options', self::PAGE_ID, array(&$this, 'generate'), CS_Manager::$plugin_url . '/img/favicon.ico');
                $this->page_hook = add_submenu_page(CS_Page_Home::PAGE_ID, __('Home', 'cslang'), __('Home', 'cslang'), 'manage_options', self::PAGE_ID, array(&$this, 'generate'));
                add_action('admin_print_scripts-' . $this->page_hook, array($this, 'enqueue_scripts'));
                add_action('admin_print_styles-' . $this->page_hook, array($this, 'enqueue_styles'));
                add_action('load-' . $this->page_hook, array(&$this, 'init'));
            }
        }
        /**
         * Init Process
         */
        function Init()
        {
            if ($this->ajax_validation_process_custom() == 1) {
                if (isset($_POST['customerrmsg']) && !empty($_POST['customerrmsg']) && isset($_POST['custommail']) && !empty($_POST['custommail'])) {
                    global $wpdb;
                    //                    $wpdb->query( "UPDATE `wp_cs_custom_set` SET set_value = 'An error occured when submitting this form, please contact us via email' WHERE set_type = 'error_msg';" );
                    $wpdb->query("UPDATE `wp_cs_custom_set` SET set_value = '" . $_POST['customerrmsg'] . "' WHERE set_type = 'error_msg';");
                    $wpdb->query("UPDATE `wp_cs_custom_set` SET set_value = '" . $_POST['custommail'] . "' WHERE set_type = 'custom_mailid';");
                }
                if (CS_Manager::is_done_validation()) {
                    $this->forms = new CS_Forms_List();
                    $this->forms->prepare_items();
                }
            } else {
                wp_safe_redirect(site_url()."/wp-admin/admin.php?page=cspage_home");
                //wp_safe_redirect("https://www.cirrus-shield.fr/wp-admin/admin.php?page=cspage_home");
            }
        }
        function ajax_validation_process_custom()
        {
            global $wpdb;
            //			check_ajax_referer( 'ajax_csadmin_nonce', 'security' );
            $getdata = $wpdb->get_results("SELECT * FROM `wp_cs_login_log` WHERE 1 ORDER BY `id` DESC;");
            if ($getdata[0]->status == 'active') {
                $username = $getdata[0]->username;
                $password = $getdata[0]->password;
            } else {
                $username = '';
                $password = '';
            }
            try {
                $cirrus = new Cirrus(CS_Manager::CIRRUSSHIELD_API_URL, $username, $password);
            } catch (Exception $e) {
                print_r($e);
                exit;
                if ($e->getMessage() == 'Cirrus requires CURL module') {
                    wp_send_json('curl_no_installed');
                } else {
                    wp_send_json('curl_error');
                }
            }
            $access_token = $cirrus->get_access_tokens();
            if ($access_token != '') {
                $settings = array(
                    'username' => $username,
                    'password' => $password,
                );
                update_option(CS_Manager::MAIN_OPTION_NAME, $settings);
                CS_Manager::$username = $username;
                CS_Manager::$password = $password;
                $token_settings = array(
                    'access_token' => $access_token,
                );
                update_option(CS_Manager::ACCESS_TOKEN_OPTION_NAME, $token_settings);
                //                                 get default language at CirrusShield.
                // create tables for users and forms.
                //                                CS_Model_Users::createTable();
                //                                CS_Forms::createTable(); // create default form also
                //                                // If the client don't have attributes regarding Double OptIn then we will create these.
                //                                CS_API_Manager::create_default_dopt();
                return 1;
            } else {
                if (!$wpdb) {
                    $wpdb = new WPDB('root', '', 'worddumb', 'localhost');
                } else {
                    global $wpdb;
                }
                $wpdb->query("DELETE FROM `wp_options` WHERE `option_name` = 'csmain_option'");
                $index = $wpdb->get_var('SELECT `id` FROM wp_cslog ORDER BY `id` DESC LIMIT 1 ;');
                $wpdb->query("UPDATE `wp_cslog` SET logouttime = '" . time() . "', status = 'Auto Logged-Out due to Invalid credential.' WHERE id = " . $index . ";");
                $index1 = $wpdb->get_var('SELECT `id` FROM wp_cs_login_log ORDER BY `id` DESC LIMIT 1 ;');
                $wpdb->query("UPDATE `wp_cs_login_log` SET status = 'deactive' WHERE id = " . $index1 . ";");
                return 0;
            }
        }
        /**
         * Enqueue scripts of plugin
         */
        function enqueue_scripts()
        {
            wp_enqueue_script('cs-admin-js');
            wp_enqueue_script('cs-bootstrap-js');
            wp_localize_script(
                'cs-admin-js',
                'ajax_csobject',
                array(
                    'ajax_url' => admin_url('admin-ajax.php'),
                    'ajax_nonce' => wp_create_nonce('ajax_csadmin_nonce'),
                    'compliance_note' => $this->defaultComplianceNote
                )
            );
            wp_localize_script(
                'cs-admin-js', 
                'csimg_url',
                array(
                    'flag_url' => plugins_url('img/flags/', __FILE__),
                    //CS_Manager::$plugin_url . '/img/flags/'
                )
            );
        }
        /**
         * Enqueue style sheets of plugin
         */
        function enqueue_styles()
        {
            wp_enqueue_style('cs-admin-css');
            wp_enqueue_style('cs-bootstrap-css');
            wp_enqueue_style('cs-fontawesome-css');
            wp_enqueue_style('thickbox');
        }
        /** Generate page script */
        function generate()
        {
            echo '<style>.wp-first-item{display:none;}</style>';
?>
            <div id="wrap" class="wrap box-border-box container-fluid">
                <h1><img id="logo-img" src="<?php echo esc_url(CS_Manager::$plugin_url . '/img/logo.png'); ?>">
                    <?php
                    $return_btn = 'none';
                    if (CS_Manager::is_done_validation() && isset($_GET['id'])) {
                        $return_btn = 'inline-block';
                    }
                    ?>
                    <a href="<?php echo esc_url(add_query_arg('page', self::PAGE_ID, admin_url('admin.php'))); ?>" class="button" style="margin-top: 6px; display: <?php echo esc_attr($return_btn); ?>;"><?php esc_attr_e('Back to form\'s list', 'cslang'); ?></a>
                    <a href="<?php echo esc_url(add_query_arg('page', 'cspage_lists', admin_url('admin.php'))); ?>" class="button" style="margin-top: 6px;"><?php esc_attr_e('Go to subscription List', 'cslang'); ?></a>
                    <a href="<?php echo esc_url(add_query_arg('page', 'cspage_log', admin_url('admin.php'))); ?>" class="button" style="margin-top: 6px;"><?php esc_attr_e('Go to Sign-In Log', 'cslang'); ?></a>
                    <a href="<?php echo esc_url(add_query_arg('page', 'cspage_customformlog', admin_url('admin.php'))); ?>" class="button" style="margin-top: 6px;"><?php esc_attr_e('Go to Un-submitted Forms Log', 'cslang'); ?></a>
                    <a href="<?php echo esc_url(add_query_arg('logoutcs', 'loginout', admin_url('admin.php'))); ?>" class="button" style="margin-top: 6px;"><?php esc_attr_e('Logout', 'cslang'); ?></a>
                </h1>
                <div id="wrap-left" class="box-border-box col-md-9 ">
                    <!--<input type="hidden" class="cs-dateformat" value="<?php // echo esc_attr($config['data']['date_format']); ?>">-->
                    <?php
                    if (CS_Manager::is_done_validation()) {
                        if ((isset($_GET['action']) && 'edit' === $_GET['action']) || (isset($_GET['action']) && 'duplicate' === $_GET['action'])) {
                            $this->formID = isset($_GET['id']) ? sanitize_text_field($_GET['id']) : 'new';
                            $this->generate_form_edit();
                        } else {
                            $this->generate_forms_page();
                        }
                    } else {
                        $this->generate_welcome_page();
                    }
                    ?>
                </div>
                <div id="wrap-right-side" class="box-border-box col-md-3">
                    <?php
                    CS_Page_Home::generate_side_bar();
                    ?>
                </div>
            </div>
            <div id="csmodal" class="modal fade" role="dialog">
                <div class="modal-dialog">
                    <div class="modal-content">
                        <div class="modal-header">
                            <button type="button" class="close" data-dismiss="modal">&times;</button>
                            <h4><?php esc_attr_e('You are about to change the language', 'cslang'); ?></h4>
                        </div>
                        <div class="modal-body">
                            <p><?php esc_attr_e("Please make sure that you've saved all the changes. We will have to reload the page.", 'cslang'); ?></p>
                            <p><?php esc_attr_e('Do you want to continue?', 'cslang'); ?></p>
                        </div>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-default" id="csmodal_ok"><?php esc_attr_e('Ok', 'cslang'); ?></button>
                            <button type="button" class="btn btn-default" id="csmodal_cancel"><?php esc_attr_e('Cancel', 'cslang'); ?></button>
                        </div>
                    </div>
                </div>
            </div>
        <?php
        }
        /** Generate forms page */
        function generate_forms_page()
        {
        ?>
            <div id="main-content" class="cs-content">
                <div class="panel panel-default row small-content">
                    <?php
                    global $wpdb;
                    //			check_ajax_referer( 'ajax_csadmin_nonce', 'security' );
                    $getdata_custom = $wpdb->get_results("SELECT * FROM `wp_cs_custom_set` WHERE 1;");
                    if (count($getdata_custom)) {
                        $ermsg = $getdata_custom[0]->set_value;
                        $emailcs = $getdata_custom[1]->set_value;
                    } else {
                        $ermsg = '';
                        $emailcs = '';
                    }
                    ?>
                    <div class="page-header"><strong><?php esc_attr_e('Action for Un-submitted Forms(While Plugin is Deactive)', 'cslang'); ?></strong></div>
                    <form method="post" action="" class="cs-forms-wrapper" style="padding:20px;">
                        <table style="border-collapse: collapse;width: 100%;">
                            <tr>
                                <td style="border: 1px solid #dddddd;text-align: left;padding: 8px;"><label><?php esc_attr_e('Error Message', 'cslang'); ?></label></td>
                                <td style="border: 1px solid #dddddd;text-align: left;padding: 8px;"><input id="customerrmsg" name="customerrmsg" value="<?php echo $ermsg ?>" style="width: -webkit-fill-available"></td>
                            </tr>
                            <tr>
                                <td style="border: 1px solid #dddddd;text-align: left;padding: 8px;"><label><?php esc_attr_e('E-Mail Id where un-submitted forms are to be forwarded', 'cslang'); ?></label></td>
                                <td style="border: 1px solid #dddddd;text-align: left;padding: 8px;"><input id="custommail" value="<?php echo $emailcs ?>" name="custommail" style="width: -webkit-fill-available"></td>
                            </tr>
                        </table>
                        <button type="submit" class="btn btn-primary" style="float: right;margin: 7px 1px 8px 15px;">Save</button>
                    </form>
                </div>
            </div>
            <div id="main-content" class="cs-content">
                <div class="panel panel-default row small-content">
                    <div class="page-header"><strong><?php esc_attr_e('Manage your forms here. You can create multiple forms that could send data to Cirrus Shield', 'cslang'); ?></strong></div>
                    <form method="post" class="cs-forms-wrapper" style="padding:20px;min-height: 500px;">
                        <!--<i style="font-size: 13px;"><?php // esc_attr_e( "Note: Forms created in CirrusShield plugin for WordPress won't be displayed in Forms section in CirrusShield application", 'cslang' );  
                                                        ?></i>-->
                        <?php
                        $this->forms->display();
                        ?>
                    </form>
                </div>
            </div>
            <?php
        }
        /** Generate form edit page */
        function generate_form_edit()
        {
            $is_activated_smtp = 0;
            //            $is_activated_smtp = CS_API_Manager::get_smtp_status() == 'disabled' ? 0 : 1;
            if ($this->formID == 'new') {
                $cirrus = new Cirrus(CS_Manager::CIRRUSSHIELD_API_URL, CS_Manager::$username, CS_Manager::$password);
                $token = $cirrus->get_access_tokens();
                $modules = $cirrus->get_modules($token);
            ?>
                <div id="main-content" class="cs-content">
                    <form action="admin.php" class="" method="post" role="form">
                        <input type="hidden" name="action" value="cssetting_subscription">
                        <input type="hidden" name="csform_id" value="<?php echo esc_attr($this->formID); ?>">
                        <input type="hidden" id="is_smtp_activated" value="<?php echo esc_attr($is_activated_smtp); ?>">
                        <input type="hidden" name="csform_name" value="<?php // echo esc_attr($formData['title']); ?>" style="width: 60%;" required="required" />
                        <?php wp_nonce_field('cssetting_subscription'); ?>
                        <div class="panel panel-default row small-content">
                            <div class="page-header">
                                <strong><?php esc_attr_e('Create New form', 'cslang'); ?></strong>
                            </div>
                            <div style="padding: 24px 32px; margin-bottom: 12px;">
                                <?php esc_attr_e('Select Cirrus Shield module to map this form to', 'cslang'); ?>: &nbsp;
                                <select name="moduleID">
                                    <?php
                                    foreach ($modules as $module) {
                                        if ($module['IsCustom']) {
                                            echo '<option value="' . $module['APIName'] . '">' . $module['Label'] . '</option>';
                                        }
                                    }
                                    ?>
                                </select>
                                &nbsp;&nbsp;<button class="btn btn-primary"><?php esc_attr_e('Next', 'cslang'); ?></button>
                            </div>
                        </div>
                    </form>
                </div>
                <?php
            } else {
                $formData = CS_Forms::getForm($this->formID);
                $invisibleCaptcha = '1';
				if (!empty($formData)) {
                    if (isset($_GET['action']) && 'duplicate' === $_GET['action']) {
                        $this->formID      = 'duplicate';
                        $formData['title'] = $formData['title'] . ' ' . 'Copy';
                    }
                    if ('new' === $this->formID && isset($_GET['pid'])) {
                        $parent_formData = CS_Forms::getForm(sanitize_text_field($_GET['pid']));
                        $formData['title'] = $parent_formData['title'];
                    }
                    if (!isset($formData['gCaptcha'])) {
                        $gCaptcha = '0';
                    } else {
                        if ('0' == $formData['gCaptcha']) {
                            $gCaptcha = '0';
                        } else {
                            $gCaptcha = '1';
                        }
                        if ('3' == $formData['gCaptcha']) {
                            $invisibleCaptcha = '0';
                        } else {
                            $invisibleCaptcha = '1';
                        }
                    }
                    if (!isset($formData['termAccept'])) {
                        $formData['termAccept'] = '0';
                    }
                    $cirrus = new Cirrus(CS_Manager::CIRRUSSHIELD_API_URL, CS_Manager::$username, CS_Manager::$password);
                    $token = $cirrus->get_access_tokens();
                    $module = $cirrus->get_module($formData['moduleID'], $token);
                ?>
                    <div id="main-content" class="cs-content">
                        <form action="admin.php" class="" method="post" role="form">
                            <input type="hidden" name="action" value="cssetting_subscription">
                            <input type="hidden" name="csform_id" value="<?php echo esc_attr($this->formID); ?>">
                            <input type="hidden" name="moduleID" value="<?php echo esc_attr($formData['moduleID']); ?>">
                            <input type="hidden" id="is_smtp_activated" value="<?php echo esc_attr($is_activated_smtp); ?>">
                            <?php
                            if (isset($_GET['pid'])) {
                            ?>
                                <input type="hidden" name="pid" value="<?php echo esc_attr(sanitize_text_field($_GET['pid'])); ?>">
                                <?php if (isset($_GET['lang'])) { ?>
                                    <input type="hidden" name="lang" value="<?php echo esc_attr(sanitize_text_field($_GET['lang'])); ?>">
                            <?php
                                }
                            }
                            ?>
                            <?php wp_nonce_field('cssetting_subscription'); ?>
                            <!-- Subscription form -->
                            <div class="panel panel-default row small-content">
                                <!--							<div class="page-header">
                                                                                                <strong><?php esc_attr_e('Subscription form', 'cslang'); ?></strong>&nbsp;<i
                                                                                                        id="cssetting_form_spin" class="fa fa-spinner fa-spin fa-fw fa-lg fa-2x"></i>
                                                                                        </div>-->
                                <div id="cssetting_form_body" class="panel-body">
                                    <div class="row <!--small-content-->" style="margin: 12px 0 34px 0px;">
                                        <div class="col-md-6" style="padding: 0">
                                            <b><?php esc_attr_e('Form Name : ', 'cslang'); ?></b>&nbsp; <input type="text" name="csform_name" value="<?php echo esc_attr(($formData['title'] != '') ? $formData['title'] : $module['Label'] . ' Form'); ?>" style="width: 60%;" required="required" />
                                        </div>
                                        <div class="col-md-6">
                                            <b><?php esc_attr_e('Related Module : ', 'cslang'); ?></b>&nbsp; <?php echo esc_attr($module['Label']); ?>
                                        </div>
                                    </div>
                                    <div class="row <!--small-content-->">
                                        <div class="col-md-6">
                                            <?php
                                            if (function_exists('wp_editor')) {
                                                wp_editor(
                                                    $formData['html'],
                                                    'sibformmarkup',
                                                    array(
                                                        'tinymce' => false,
                                                        'media_buttons' => true,
                                                        'textarea_name' => 'csform_html',
                                                        'textarea_rows' => 15,
                                                    )
                                                );
                                            } else {
                                            ?>
                                                <textarea class="widefat" cols="160" rows="20" id="sibformmarkup" name="csform_html"><?php echo esc_textarea($formData['html']); ?></textarea>
                                            <?php
                                            }
                                            ?>
                                            <br>
                                            <p>
                                                <?php
                                                esc_attr_e('Use the shortcode', 'cslang');
                                                if (isset($_GET['pid'])) {
                                                    $id = sanitize_text_field($_GET['pid']);
                                                } else {
                                                    // $id = 'new' !== $this->formID ? $this->formID : '';
                                                    if ('new' === $this->formID || 'duplicate' === $this->formID) {
                                                        $id   = '';
                                                    } else {
                                                        $id   = $this->formID;
                                                    }
                                                }
                                                ?>
                                                <i style="background-color: #eee;padding: 3px;">[cswp_form
                                                    id=<?php echo esc_attr($id); ?>]</i>
                                                <?php
                                                esc_attr_e('inside a post, page or text widget to display your sign-up form.', 'cslang');
                                                ?>
                                                <b><?php esc_attr_e('Do not copy and paste the above form mark up, that will not work', 'cslang'); ?></b>
                                            </p>
                                            <div id="cs-field-form" class="panel panel-default row form-field" style="padding-bottom: 20px;">
                                                <div class="row small-content2" style="margin-top: 15px;margin-bottom: 15px;">
                                                    <b><?php esc_attr_e('Add a new Field', 'cslang'); ?></b>&nbsp;
                                                    <?php CS_Page_Home::get_narration_script(__('Add a New Field', 'cslang'), __('Choose an attribute and add it to the subscription form of your Website', 'cslang')); ?>
                                                </div>
                                                <div id="cssel_attribute_area" class="row small-content2" style="margin-top: 20px;">
                                                    <!--   <select class="col-md-12" id="cssel_attribute">
                                                        <option value="-1" disabled="" selected="">Select CirrusShield Attribute</option>
                                                        <optgroup label="CirrusShield merge fields : Normal">
                                                            <option value="email">Email Address*</option>
                                                            <?php
                                                            foreach ($module['Fields'] as $field) {
                                                                if ($field['IsCustom']) {
                                                                    echo '<option value="' . $field['Name'] . '">' . $field['Label'] . '</option>';
                                                                }
                                                            }
                                                            ?>
                                                        </optgroup>
                                                        <optgroup label="CirrusShield merge fields : Category"></optgroup>
                                                        <optgroup label="Other">
                                                            <option value="submit">Submit Button</option>
                                                        </optgroup>
                                                    </select>-->
                                                </div>
                                                <div id="cs-field-content">
                                                    <div style="margin-top: 30px;">
                                                        <div class="cs-attr-normal cs-attr-category row small-content2" style="margin-top: 10px;" id="csfield_label_area">
                                                            <?php esc_attr_e('Label', 'cslang'); ?>
                                                            <small>(<?php esc_attr_e('Optional', 'cslang'); ?>)</small>
                                                            <input type="text" class="col-md-12 csfield_changes" id="csfield_label">
                                                        </div>
                                                        <div class="cs-attr-normal row small-content2" style="margin-top: 10px;" id="csfield_placeholder_area">
                                                            <span><?php esc_attr_e('Place holder', 'cslang'); ?>
                                                                <small>(<?php esc_attr_e('Optional', 'cslang'); ?>)
                                                                </small> </span>
                                                            <input type="text" class="col-md-12 csfield_changes" id="csfield_placeholder">
                                                        </div>
                                                        <div class="cs-attr-normal row small-content2" style="margin-top: 10px;" id="csfield_initial_area">
                                                            <span><?php esc_attr_e('Initial value', 'cslang'); ?>
                                                                <small>(<?php esc_attr_e('Optional', 'cslang'); ?>)
                                                                </small> </span>
                                                            <input type="text" class="col-md-12 csfield_changes" id="csfield_initial">
                                                        </div>
                                                        <div class="cs-attr-other row small-content2" style="margin-top: 10px;" id="csfield_button_text_area">
                                                            <span><?php esc_attr_e('Button Text', 'cslang'); ?></span>
                                                            <input type="text" class="col-md-12 csfield_changes" id="csfield_button_text">
                                                        </div>
                                                    </div>
                                                    <div style="margin-top: 20px;">
                                                        <div class="cs-attr-normal cs-attr-category row small-content2" style="margin-top: 5px;" id="csfield_required_area">
                                                            <label style="font-weight: normal;"><input type="checkbox" class="csfield_changes" id="csfield_required">&nbsp;&nbsp;<?php esc_attr_e('Required field ?', 'cslang'); ?>
                                                            </label>
                                                        </div>
                                                        <div class="cs-attr-category row small-content2" style="margin-top: 5px;" id="csfield_type_area">
                                                            <label style="font-weight: normal;"><input type="radio" class="csfield_changes" name="csfield_type" value="select" checked>&nbsp;<?php esc_attr_e('Drop-down List', 'cslang'); ?>
                                                            </label>&nbsp;&nbsp;
                                                            <label style="font-weight: normal;"><input type="radio" class="csfield_changes" name="csfield_type" value="radio">&nbsp;<?php esc_attr_e('Radio List', 'cslang'); ?>
                                                            </label>
                                                        </div>
                                                    </div>
                                                    <div class="row small-content2" style="margin-top: 20px;" id="csfield_add_area">
                                                        <button type="button" id="csadd_to_form_btn" class="btn btn-default cs-add-to-form"><span class="cs-large-icon">
                                                                <</span> <?php esc_attr_e('Add to form', 'cslang'); ?> </button>&nbsp;&nbsp; <?php CS_Page_Home::get_narration_script(__('Add to form', 'cslang'), __('Please click where you want to insert the field and click on this button. By default, the new field will be added at top.', 'cslang')); ?> </div> <div class="row small-content2" style="margin-top: 20px;" id="csfield_html_area">
                                                                    <span><?php esc_attr_e('Generated HTML', 'cslang'); ?></span>
                                                                    <textarea class="col-md-12" style="height: 140px;" id="csfield_html"></textarea>
                                                    </div>
                                                </div>
                                            </div>
                                            <!---- multi list per interest ----->
                                            <!--                                        <div id="cs-multi-lists" class="panel panel-default row form-field"
                                                                                         style="padding-bottom: 20px;">
                                                                                        <div class="row small-content2"
                                                                                             style="margin-top: 15px;margin-bottom: 15px;">
                                                                                            <b><?php esc_attr_e('Add Multi-List Subscription', 'cslang'); ?></b>&nbsp;
                    <?php CS_Page_Home::get_narration_script(__('Add Multi-List Subscription', 'cslang'), __('Enable your contacts to subscribe to content based on specific interests or preferences. Create a contact list for each interest and allow them to subscribe using this field', 'cslang')); ?>
                                                                                        </div>
                                                                                        <div id="cssel_multi_list_area" class="row small-content2"
                                                                                             style="margin-top: 20px;">
                                                                                            <input type="hidden" id="csselected_multi_list_id" value="">
                                                                                            <select data-placeholder="<?php esc_attr_e('Please select the lists', 'cslang'); ?>" id="csselect_multi_list"
                                                                                                    class="col-md-12" name="multi_list_ids[]" multiple=""
                                                                                                    tabindex="-1"></select>
                                                                                        </div>
                                                                                        <div id="csmulti_list_field" style="display: none;">
                                                                                            <div style="margin-top: 30px;">
                                                                                                <div class="cs-attr-normal cs-attr-category row small-content2"
                                                                                                     style="margin-top: 10px;" id="csmulti_field_label_area">
                    <?php esc_attr_e('Label', 'cslang'); ?>
                                                                                                    <small>(<?php esc_attr_e('Optional', 'cslang'); ?>)</small>
                                                                                                    <input type="text" class="col-md-12 csfield_changes" id="csmulti_field_label">
                                                                                                </div>
                                                                                            </div>
                                                                                            <div style="margin-top: 20px;">
                                                                                                <div class="cs-attr-normal cs-attr-category row small-content2" style="margin-top: 5px;" id="csmulti_field_required_area">
                                                                                                    <label style="font-weight: normal;"><input type="checkbox" class="csfield_changes" id="csmulti_field_required">&nbsp;&nbsp;<?php esc_attr_e('Required field ?', 'cslang'); ?>
                                                                                                    </label>
                                                                                                </div>
                                                                                            </div>
                                                                                            <div class="row small-content2" style="margin-top: 20px;"
                                                                                                 id="csmulti_field_add_area">
                                                                                                <button type="button" id="csmulti_lists_add_form_btn"
                                                                                                        class="btn btn-default cs-add-to-form"><span
                                                                                                            class="cs-large-icon"><</span> <?php esc_attr_e('Add to form', 'cslang'); ?>
                                                                                                </button>&nbsp;&nbsp;
                    <?php CS_Page_Home::get_narration_script(__('Add to form', 'cslang'), __('Please click where you want to insert the field and click on this button. By default, the new field will be added at top.', 'cslang')); ?>
                                                                                            </div>
                                                                                            <div class="row small-content2" style="margin-top: 20px;"
                                                                                                 id="csfield_html_area">
                                                                                                <span><?php esc_attr_e('Generated HTML', 'cslang'); ?></span>
                                                                                                <textarea class="col-md-12" style="height: 140px;"
                                                                                                          id="csmulti_field_html"></textarea>
                                                                                            </div>
                                                                                        </div>
                                                                                    </div>-->
                                            <div id="cs-gdpr-block" class="panel panel-default row form-field" style="padding-bottom: 20px;">
                                                <div class="row small-content2" style="margin-top: 15px;margin-bottom: 15px;">
                                                    <b><?php esc_attr_e('Compliance Note', 'cslang'); ?></b>&nbsp;
                                                    <?php CS_Page_Home::get_narration_script(__('Add compliance note', 'cslang'), __('Create GDPR-compliant subscription forms for collecting email addresses.', 'cslang')); ?>
                                                </div>
                                                <div class="row small-content2" style="margin-top: 0px;">
                                                    <input type="radio" name="csadd_compliant_note" class="cs-add-compliant-note" value="1"><label class="cs-radio-label">&nbsp;<?php esc_attr_e('Yes', 'cslang'); ?></label>
                                                    <input type="radio" name="csadd_compliant_note" class="cs-add-compliant-note" value="0" checked><label class="cs-radio-label">&nbsp;<?php esc_attr_e('No', 'cslang'); ?></label>
                                                </div>
                                                <div class="row small-content2 cs-gdpr-block-area" style="display: none;">
                                                    <textarea id="csgdpr_text" class="col-md-12" rows="5"><?php echo trim($this->defaultComplianceNote); ?></textarea>
                                                    <label id="set_gdpr_default"><?php esc_attr_e('Reset to Default', 'cslang'); ?>&nbsp;<i class="fa fa-refresh"></i></label>
                                                </div>
                                                <div class="row small-content2 cs-gdpr-block-btn" style="display: none;">
                                                    <button type="button" id="csadd_compliance_note" class="btn btn-default cs-add-to-form"><span class="cs-large-icon">
                                                            <</span> <?php esc_attr_e('Add to form', 'cslang'); ?> </button>&nbsp;&nbsp; <?php CS_Page_Home::get_narration_script(__('Add to form', 'cslang'), __('Please click where you want to insert the field and click on this button. By default, the new field will be added at top.', 'cslang')); ?> </div> </div> <!---- end block ------>
                                                                <div id="csform_captcha" class="panel panel-default row form-field" style="padding-bottom: 20px;">
                                                                    <div class="alert alert-danger" style="margin:5px;display: none;"></div>
                                                                    <div class="row small-content2" style="margin-top: 15px;margin-bottom: 15px;">
                                                                        <b><?php esc_attr_e('Add Captcha', 'cslang'); ?></b>&nbsp;
                                                                        <?php CS_Page_Home::get_narration_script(__('Add Captcha', 'cslang'), __('We are using Google reCaptcha for this form. To use Google reCaptcha on this form, you should input site key and secret key.', 'cslang')); ?>
                                                                    </div>
                                                                    <div class="row small-content2" style="margin-top: 0px;">
                                                                        <input type="radio" name="csadd_captcha" class="cs-add-captcha" value="1" <?php checked($gCaptcha, '1'); ?>><label class="cs-radio-label">&nbsp;<?php esc_attr_e('Yes', 'cslang'); ?></label>
                                                                        <input type="radio" name="csadd_captcha" class="cs-add-captcha" value="0" <?php checked($gCaptcha, '0'); ?>><label class="cs-radio-label">&nbsp;<?php esc_attr_e('No', 'cslang'); ?></label>
                                                                    </div>
                                                                    <div class="row small-content2 cs-captcha-key" <?php
                                                                                                                    if ('1' !== $gCaptcha) {
                                                                                                                        echo ("style='display: none;'");
                                                                                                                    }
                                                                                                                    ?>>
                                                                        <i><?php esc_attr_e('Site Key', 'cslang'); ?></i>&nbsp;
                                                                        <input type="text" class="col-md-12" id="cscaptcha_site" name="cscaptcha_site" value="<?php
                                                                                                                                                                if (isset($formData['gCaptcha_site']) && !empty($formData['gCaptcha_site'])) {
                                                                                                                                                                    echo esc_attr($formData['gCaptcha_site']);
                                                                                                                                                                } else {
                                                                                                                                                                    echo '';
                                                                                                                                                                }
                                                                                                                                                                ?>">
                                                                    </div>
                                                                    <div class="row small-content2 cs-captcha-key" <?php
                                                                                                                    if ('1' !== $gCaptcha) {
                                                                                                                        echo ("style='display: none;'");
                                                                                                                    }
                                                                                                                    ?>>
                                                                        <i><?php esc_attr_e('Secret Key', 'cslang'); ?></i>&nbsp;
                                                                        <input type="text" class="col-md-12" id="cscaptcha_secret" name="cscaptcha_secret" value="<?php
                                                                                                                                                                    if (isset($formData['gCaptcha_secret']) && !empty($formData['gCaptcha_secret'])) {
                                                                                                                                                                        echo esc_attr($formData['gCaptcha_secret']);
                                                                                                                                                                    } else {
                                                                                                                                                                        echo '';
                                                                                                                                                                    }
                                                                                                                                                                    ?>">
                                                                    </div>
                                                                    <div class="row small-content2 cs-captcha-key" <?php
                                                                                                                    if ('1' !== $gCaptcha) {
                                                                                                                        echo ("style='display: none;'");
                                                                                                                    }
                                                                                                                    ?>>
                                                                        <input type="radio" name="csrecaptcha_type" class="cs-captcha-type" value="0" <?php checked($invisibleCaptcha, '0'); ?>><label class="cs-radio-label">&nbsp;<?php esc_attr_e('Google Captcha', 'cslang'); ?></label>
                                                                        <input type="radio" name="csrecaptcha_type" class="cs-captcha-type" value="1" <?php checked($invisibleCaptcha, '1'); ?>><label class="cs-radio-label">&nbsp;<?php esc_attr_e('Google Invisible Captcha', 'cslang'); ?></label>
                                                                    </div>
                                                                    <div class="row small-content2 cs-captcha-key" <?php
                                                                                                                    if ('1' !== $gCaptcha) {
                                                                                                                        echo ("style='display: none;'");
                                                                                                                    }
                                                                                                                    ?>>
                                                                        <button type="button" id="csadd_captcha_btn" class="btn btn-default cs-add-to-form"><span class="cs-large-icon">
                                                                                <</span> <?php esc_attr_e('Add to form', 'cslang'); ?> </button>&nbsp;&nbsp; <?php CS_Page_Home::get_narration_script(__('Add Captcha', 'cslang'), __('Please click where you want to insert the field and click on this button. By default, the new field will be added at top.', 'cslang')); ?> </div> </div> <div id="csform_terms" class="panel panel-default row form-field" style="padding-bottom: 20px;">
                                                                                    <div class="alert alert-danger" style="margin:5px;display: none;"></div>
                                                                                    <!-- for terms -->
                                                                                    <div class="row small-content2" style="margin-top: 15px;margin-bottom: 15px;">
                                                                                        <b><?php esc_attr_e('Add a Term acceptance checkbox', 'cslang'); ?></b>&nbsp;
                                                                                        <?php CS_Page_Home::get_narration_script(__('Add a Term acceptance checkbox', 'cslang'), __('If the terms and condition checkbox is added to the form, the field will be mandatory for subscription.', 'cslang')); ?>
                                                                                    </div>
                                                                                    <div class="row small-content2" style="margin-top: 0px;">
                                                                                        <input type="radio" name="csadd_terms" class="cs-add-terms" value="1" <?php checked($formData['termAccept'], '1'); ?>><label class="cs-radio-label">&nbsp;<?php esc_attr_e('Yes', 'cslang'); ?></label>
                                                                                        <input type="radio" name="csadd_terms" class="cs-add-terms" value="0" <?php checked($formData['termAccept'], '0'); ?>><label class="cs-radio-label">&nbsp;<?php esc_attr_e('No', 'cslang'); ?></label>
                                                                                    </div>
                                                                                    <div class="row small-content2 cs-terms-url" <?php
                                                                                                                                    if ('1' !== $formData['termAccept']) {
                                                                                                                                        echo ("style='display: none;'");
                                                                                                                                    }
                                                                                                                                    ?>>
                                                                                        <i><?php esc_attr_e('URL to terms and conditions', 'cslang'); ?></i>&nbsp;
                                                                                        <input type="text" class="col-md-12" id="csterms_url" name="csterms_url" value="<?php
                                                                                                                                                                        if (isset($formData['termsURL']) && !empty($formData['termsURL'])) {
                                                                                                                                                                            echo esc_attr($formData['termsURL']);
                                                                                                                                                                        } else {
                                                                                                                                                                            echo '';
                                                                                                                                                                        }
                                                                                                                                                                        ?>">
                                                                                    </div>
                                                                                    <div class="row small-content2 cs-terms-url" <?php
                                                                                                                                    if ('1' !== $formData['termAccept']) {
                                                                                                                                        echo ("style='display: none;'");
                                                                                                                                    }
                                                                                                                                    ?>>
                                                                                        <button type="button" id="csadd_termsUrl_btn" class="btn btn-default cs-add-to-form"><span class="cs-large-icon">
                                                                                                <</span> <?php esc_attr_e('Add to form', 'cslang'); ?> </button>&nbsp;&nbsp; <?php CS_Page_Home::get_narration_script(__('Add Terms URL', 'cslang'), __('Please click where you want to insert the field and click on this button. By default, the new field will be added at top.', 'cslang')); ?> </div> </div> <!-- use css of custom or theme -->
                                                                                                    <div class="panel panel-default row form-field">
                                                                                                        <div class="row small-content2" style="margin-top: 15px;margin-bottom: 10px;">
                                                                                                            <b><?php esc_attr_e('Form Style', 'cslang'); ?>&nbsp;</b>
                                                                                                            <?php CS_Page_Home::get_narration_script(__('Form Style', 'cslang'), __('Select the style you favorite. Your custom css will be applied to form only.', 'cslang')); ?>
                                                                                                        </div>
                                                                                                        <div id="csform_css_area" class="row small-content2" style="margin-bottom: 15px;">
                                                                                                            <label style="font-weight: normal;"><input type="radio" name="cscss_type" value="1" <?php checked($formData['dependTheme'], '1'); ?>>&nbsp;<?php esc_attr_e('Current Theme', 'cslang'); ?>
                                                                                                            </label>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
                                                                                                            <label style="font-weight: normal;"><input type="radio" name="cscss_type" value="0" <?php checked($formData['dependTheme'], '0'); ?>>&nbsp;<?php esc_attr_e('Custom style', 'cslang'); ?>
                                                                                                            </label>
                                                                                                            <textarea class="widefat" cols="60" rows="10" id="sibcssmarkup" style="width: 100%; margin-top: 10px; font-size: 13px; display: <?php echo '0' == $formData['dependTheme'] ? 'block' : 'none'; ?>;" name="csform_css"><?php echo esc_textarea($formData['css']); ?></textarea>
                                                                                                        </div>
                                                                                                    </div>
                                                                                    </div>
                                                                                    <div class="col-md-6">
                                                                                        <!-- hidden fields for attributes -->
                                                                                        <input type="hidden" id="cshidden_email" data-type="email" data-name="email" data-text="<?php esc_attr_e('Email Address', 'cslang'); ?>">
                                                                                        <input type="hidden" id="cshidden_submit" data-type="submit" data-name="submit" data-text="<?php esc_attr_e('Subscribe', 'cslang'); ?>">
                                                                                        <input type="hidden" id="cshidden_message_1" value="<?php esc_attr_e('Select CirrusShield Attribute', 'cslang'); ?>">
                                                                                        <input type="hidden" id="cshidden_message_2" value="<?php esc_attr_e('CirrusShield merge fields : Normal', 'cslang'); ?>">
                                                                                        <input type="hidden" id="cshidden_message_3" value="<?php esc_attr_e('CirrusShield merge fields : Category', 'cslang'); ?>">
                                                                                        <input type="hidden" id="cshidden_message_4" value="<?php esc_attr_e('Other', 'cslang'); ?>">
                                                                                        <input type="hidden" id="cshidden_message_5" value="<?php esc_attr_e('Submit Button', 'cslang'); ?>">
                                                                                        <!-- preview field -->
                                                                                        <div class="panel panel-default row form-field">
                                                                                            <div class="row small-content2" style="margin-top: 15px;margin-bottom: 15px;">
                                                                                                <b><?php esc_attr_e('Preview', 'cslang'); ?>&nbsp;
                                                                                                    <span id="cs-preview-form-refresh" class="glyphicon glyphicon-refresh" style="cursor:pointer"></span></b>
                                                                                            </div>
                                                                                            <iframe id="cs-preview-form" src="<?php echo esc_url(site_url() . '/?csform=' . esc_attr($this->formID)); ?>" width="300px" height="428"></iframe>
                                                                                        </div>
                                                                                    </div>
                                                                    </div>
                                                                    <div class="row small-content" style="margin-top: 30px;">
                                                                        <div class="col-md-3">
                                                                            <button class="btn btn-primary"><?php esc_attr_e('Save', 'cslang'); ?></button>
                                                                        </div>
                                                                    </div>
                                                                </div>
                                                </div> <!-- End Subscription form-->
                                                <!-- Sign up Process -->
                                                <div class="panel panel-default row small-content">
                                                    <!-- Adding security through hidden referrer field -->
                                                    <div class="page-header">
                                                        <strong><?php esc_attr_e('Sign up process', 'cslang'); ?></strong>&nbsp;<i id="cssetting_signup_spin" class="fa fa-spinner fa-spin fa-fw fa-lg fa-2x"></i>
                                                    </div>
                                                    <div id="cssetting_signup_body" class="panel-body">
                                                        <div id="csform_alert_message" class="alert alert-danger alert-dismissable fade in" role="alert" style="display: none;">
                                                            <span id="csdisclaim_smtp" style="display: none;"><?php _e('Confirmation emails will be sent through your own email server, but you have no guarantees on their deliverability. <br/> <a href="https://app-smtp.cirrusshield.com/" target="_blank">Click here</a> to send your emails through CirrusShield in order to improve your deliverability and get statistics', 'cslang'); ?></span>
                                                            <span id="csdisclaim_do_template" style="display: none;"><?php _e('The template you selected does not include a link [DOUBLEOPTIN] to allow subscribers to confirm their subscription. <br/> Please edit the template to include a link with [DOUBLEOPTIN] as URL.', 'cslang'); ?></span>
                                                            <span id="csdisclaim_confirm_template" style="display: none;"><?php _e('You cannot select a template with the tag [DOUBLEOPTIN]', 'cslang'); ?></span>
                                                        </div>
                                                        <!-- Linked List -->
                                                        <div class="row small-content" style="display: none">
                                                            <span class="col-md-3">
                                                                <?php // esc_attr_e('Linked List', 'cslang'); 
                                                                ?>&nbsp;
                                                                <?php // CS_Page_Home::get_narration_script(__('Linked List', 'cslang'), __('Select the list where you want to add your new subscribers', 'cslang')); 
                                                                ?>
                                                            </span>
                                                            <div id="csselect_list_area" class="col-md-4">
                                                                <input type="hidden" id="csselected_list_id" value="">
                                                                <select data-placeholder="Please select the list" id="csselect_list" class="col-md-12" name="list_id[]" multiple="" tabindex="-1"></select>
                                                            </div>
                                                            <div class="col-md-5">
                                                                <small style="font-style: italic;"><?php esc_attr_e('You can use Marketing Automation to create specific workflow when a user is added to the list.', 'cslang'); ?></small>
                                                            </div>
                                                        </div>
                                                        <!-- From data to specific emails -->
                                                        <div class="row small-content">
                                                            <span class="col-md-3"><?php esc_attr_e('Send form data to specific emails when a form submitted', 'cslang'); ?></span>
                                                            <div class="col-md-4">
                                                                <label class="col-md-6" style="font-weight: normal;">
                                                                    <input type="radio" id="is_data_emails_specific_click_yes" name="is_data_emails_specific_click" value="1" checked>&nbsp;<?php esc_attr_e('Yes', 'cslang'); ?>
                                                                </label>
                                                                <label class="col-md-6" style="font-weight: normal;">
                                                                    <input type="radio" id="is_data_emails_specific_click_no" name="is_data_emails_specific_click" value="0" <?php checked($formData['emailSpecificId'], ''); ?>>&nbsp;<?php esc_attr_e('No', 'cslang'); ?>
                                                                </label>
                                                            </div>
                                                            <div class="col-md-5">
                                                                <small style="font-style: italic;"><?php esc_attr_e('Select "Yes" if you want to the form data to be sent to emails of your choice when a form is submitted', 'cslang'); ?></small>
                                                            </div>
                                                        </div>
                                                        <div class="row" style="margin-top: 10px; <?php if ($formData['emailSpecificId'] == '') { ?> display:none; <?php } ?>" id="cssubscrition_emails_specific_area">
                                                            <span class="col-md-1"></span>
                                                            <small class="col-md-6" style="font-size: 11px;padding-right: 0px;"><?php esc_attr_e('Please provide the list of emails to send the form data to (separated commas)', 'cslang'); ?></small>
                                                            <div class="col-md-5" style="padding-left: 0px;">
                                                                <input type="text" class="col-md-11" name="data_specific_emails" value="<?php echo esc_attr($formData['emailSpecificId']); ?>" placeholder="abc@abc.com,xyz@xyz.com">
                                                            </div>
                                                        </div>
                                                        <!-- //Data to specific emails -->
                                                        <!-- confirmation email -->
                                                        <div class="row small-content">
                                                            <span class="col-md-3"><?php esc_attr_e('Send a confirmation email', 'cslang'); ?><?php echo esc_html(CS_Page_Home::get_narration_script(__('Confirmation message', 'cslang'), __('You can choose to send a confirmation email. You will be able to set up the template that will be sent to your new suscribers', 'cslang'))); ?></span>
                                                            <div class="col-md-4">
                                                                <label class="col-md-6" style="font-weight: normal;"><input type="radio" id="is_confirm_email_yes" name="is_confirm_email" value="1" <?php checked($formData['isOpt'], '1'); ?>>&nbsp;<?php esc_attr_e('Yes', 'cslang'); ?>
                                                                </label>
                                                                <label class="col-md-6" style="font-weight: normal;"><input type="radio" id="is_confirm_email_no" name="is_confirm_email" value="0" <?php checked($formData['isOpt'], '0'); ?>>&nbsp;<?php esc_attr_e('No', 'cslang'); ?>
                                                                </label>
                                                            </div>
                                                            <div class="col-md-5">
                                                                <small style="font-style: italic;"><?php esc_attr_e('Select "Yes" if you want your subscribers to receive a confirmation email', 'cslang'); ?></small>
                                                            </div>
                                                        </div>
                                                        <!-- select template id for confirmation email -->
                                                        <div class="row" id="csconfirm_template_area">
                                                            <input type="hidden" id="csselected_template_id" value="<?php echo esc_attr($formData['templateID']); ?>">
                                                            <input type="hidden" id="csdefault_template_name" value="<?php esc_attr_e('Default', 'cslang'); ?>">
                                                            <div class="col-md-3" id="cstemplate_id_area">
                                                            </div>
                                                            <!--                                        <div class="col-md-4">
                                            <a href="https://my.cirrusshield.com/camp/listing#temp_active_m" class="col-md-12"
                                               target="_blank"><i
                                                    class="fa fa-angle-right"></i> <?php esc_attr_e('Set up my templates', 'cslang'); ?>
                                            </a>
                                        </div>-->
                                                        </div>
                                                        <!-- double optin confirmation email -->
                                                        <div class="row small-content">
                                                            <span class="col-md-3"><?php esc_attr_e('Double Opt-In', 'cslang'); ?><?php echo esc_html(CS_Page_Home::get_narration_script(__('Double Opt-In', 'cslang'), __('Your subscribers will receive an email inviting them to confirm their subscription. Be careful, your subscribers are not saved in your list before confirming their subscription.', 'cslang'))); ?></span>
                                                            <div class="col-md-4">
                                                                <label class="col-md-6" style="font-weight: normal;"><input type="radio" id="is_double_optin_yes" name="is_double_optin" value="1" <?php checked($formData['isDopt'], '1'); ?>>&nbsp;<?php esc_attr_e('Yes', 'cslang'); ?>
                                                                </label>
                                                                <label class="col-md-6" style="font-weight: normal;"><input type="radio" id="is_double_optin_no" name="is_double_optin" value="0" <?php checked($formData['isDopt'], '0'); ?>>&nbsp;<?php esc_attr_e('No', 'cslang'); ?>
                                                                </label>
                                                            </div>
                                                            <div class="col-md-5">
                                                                <small style="font-style: italic;"><?php esc_attr_e('Select "Yes" if you want your subscribers to confirm their email address', 'cslang'); ?></small>
                                                            </div>
                                                        </div>
                                                        <!-- select template id for double optin confirmation email -->
                                                        <div class="row" id="csdoubleoptin_template_area">
                                                            <input type="hidden" id="csselected_do_template_id" value="<?php echo esc_attr($formData['templateID']); ?>">
                                                            <div class="col-md-3">
                                                                <select id="is_email_double_optin" name="is_email_double_optin" emailDopt="<?= $formData['emailDopt'] ?>" style="display: none;"></select>
                                                            </div>
                                                            <div class="col-md-3">
                                                                <select id="is_datetime_double_optin" name="is_datetime_double_optin" datetimeDopt="<?= $formData['datetimeDopt'] ?>" style="display: none;"></select>
                                                            </div>
                                                            <!--  
                                         <div class="col-md-3" id="csdoubleoptin_template_id_area">
                                        </div> 
                                        <div class="col-md-4">
                                            <a href="https://my.cirrusshield.com/camp/listing?utm_source=wordpress_plugin&utm_medium=plugin&utm_campaign=module_link#temp_active_m"
                                               class="col-md-12" target="_blank"><i
                                                    class="fa fa-angle-right"></i> <?php esc_attr_e('Set up my templates', 'cslang'); ?>
                                            </a>
                                        </div>
                                    -->
                                                        </div>
                                                        <div class="row small-content" id="csdouble_redirect_area">
                                                            <span class="col-md-3"><?php esc_attr_e('Redirect to this URL after clicking in the email', 'cslang'); ?></span>
                                                            <div class="col-md-8">
                                                                <input type="url" class="col-md-11" name="redirect_url" value="<?php echo esc_attr($formData['redirectInEmail']); ?>">
                                                            </div>
                                                        </div>
                                                        <?php /* ?>
                                    <div class="row small-content" id="csfinal_confirm_template_area" >
                                        <span class="col-md-3"><?php esc_attr_e('Select final confirmation email template', 'cslang'); ?><?php echo esc_html(CS_Page_Home::get_narration_script(__('Final confirmation', 'cslang'), __('This is the final confirmation email your contacts will receive once they click on the double opt-in confirmation link. You can select one of the default templates we have created for you, e.g. \'Default template - Final confirmation\'.
For your information, you cannot select a template with the tag [DOUBLEOPTIN].', 'cslang'))); ?></span>
                                        <div class="col-md-8">
                                            <input type="hidden" id="csselected_confirm_template_id" value="<?php echo esc_attr($formData['confirmID']); ?>">
                                            <div class="col-md-5" id="csfinal_confirm_template_id_area">
                                            </div>
                                            <div class="col-md-4">
                                                <a href="https://my.cirrusshield.com/camp/listing?utm_source=wordpress_plugin&utm_medium=plugin&utm_campaign=module_link#temp_active_m"
                                                   class="col-md-12" target="_blank"><i
                                                        class="fa fa-angle-right"></i> <?php esc_attr_e('Set up my templates', 'cslang'); ?>
                                                </a>
                                            </div>
                                        </div>
                                    </div>
                                       <?php */ ?>
                                                        <div class="row small-content">
                                                            <span class="col-md-3"><?php esc_attr_e('Redirect to this URL after subscription', 'cslang'); ?></span>
                                                            <div class="col-md-4">
                                                                <label class="col-md-6" style="font-weight: normal;"><input type="radio" id="is_redirect_url_click_yes" name="is_redirect_url_click" value="1" checked>&nbsp;<?php esc_attr_e('Yes', 'cslang'); ?>
                                                                </label>
                                                                <label class="col-md-6" style="font-weight: normal;"><input type="radio" id="is_redirect_url_click_no" name="is_redirect_url_click" value="0" <?php checked($formData['redirectInForm'], ''); ?>>&nbsp;<?php esc_attr_e('No', 'cslang'); ?>
                                                                </label>
                                                            </div>
                                                            <div class="col-md-5">
                                                                <small style="font-style: italic;"><?php esc_attr_e('Select "Yes" if you want to redirect your subscribers to a specific page after they fullfill the form', 'cslang'); ?></small>
                                                            </div>
                                                        </div>
                                                        <div class="row" style="margin-top: 10px;
                                    <?php
                                    if ('' == $formData['redirectInForm']) {
                                        echo 'display:none;';
                                    }
                                    ?>
                                         " id="cssubscrition_redirect_area">
                                                            <span class="col-md-3"></span>
                                                            <div class="col-md-8">
                                                                <input type="url" class="col-md-11" name="redirect_url_click" value="<?php echo esc_attr($formData['redirectInForm']); ?>">
                                                            </div>
                                                        </div>
                                                        <div class="row small-content" style="margin-top: 30px;">
                                                            <div class="col-md-3">
                                                                <button class="btn btn-primary"><?php esc_attr_e('Save', 'cslang'); ?></button>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div><!-- End Sign up process form-->
                                                <!-- Confirmation message form -->
                                                <div class="panel panel-default row small-content">
                                                    <div class="page-header">
                                                        <strong><?php esc_attr_e('Confirmation message', 'cslang'); ?></strong>
                                                    </div>
                                                    <div class="panel-body">
                                                        <div class="row small-content">
                                                            <span class="col-md-3"><?php esc_attr_e('Success message', 'cslang'); ?></span>
                                                            <div class="col-md-8">
                                                                <input type="text" class="col-md-11" name="alert_success_message" value="<?php echo esc_attr($formData['successMsg']); ?>" required>&nbsp;
                                                                <?php echo esc_html(CS_Page_Home::get_narration_script(__('Success message', 'cslang'), __('Set up the success message that will appear when one of your visitors surccessfully signs up', 'cslang'))); ?>
                                                            </div>
                                                        </div>
                                                        <div class="row small-content">
                                                            <span class="col-md-3"><?php esc_attr_e('General error message', 'cslang'); ?></span>
                                                            <div class="col-md-8">
                                                                <input type="text" class="col-md-11" name="alert_error_message" value="<?php echo esc_attr($formData['errorMsg']); ?>" required>&nbsp;
                                                                <?php echo esc_html(CS_Page_Home::get_narration_script(__('General message error', 'cslang'), __('Set up the message that will appear when an error occurs during the subscritpion process', 'cslang'))); ?>
                                                            </div>
                                                        </div>
                                                        <div class="row small-content">
                                                            <span class="col-md-3"><?php esc_attr_e('Existing subscribers', 'cslang'); ?></span>
                                                            <div class="col-md-8">
                                                                <input type="text" class="col-md-11" name="alert_exist_subscriber" value="<?php echo esc_attr($formData['existMsg']); ?>" required>&nbsp;
                                                                <?php echo esc_html(CS_Page_Home::get_narration_script(__('Existing Suscribers', 'cslang'), __('Set up the message that will appear when a suscriber is already in your database', 'cslang'))); ?>
                                                            </div>
                                                        </div>
                                                        <div class="row small-content">
                                                            <span class="col-md-3"><?php esc_attr_e('Invalid email address', 'cslang'); ?></span>
                                                            <div class="col-md-8">
                                                                <input type="text" class="col-md-11" name="alert_invalid_email" value="<?php echo esc_attr($formData['invalidMsg']); ?>" required>&nbsp;
                                                                <?php echo esc_html(CS_Page_Home::get_narration_script(__('Invalid email address', 'cslang'), __('Set up the message that will appear when the email address used to sign up is not valid', 'cslang'))); ?>
                                                            </div>
                                                        </div>
                                                        <div class="row small-content">
                                                            <span class="col-md-3"><?php esc_attr_e('Required Field', 'cslang'); ?></span>
                                                            <div class="col-md-8">
                                                                <input type="text" class="col-md-11" name="alert_required_message" value="<?php echo esc_attr($formData['requiredMsg']); ?>" required>&nbsp;
                                                                <?php echo esc_html(CS_Page_Home::get_narration_script(__('Required Field', 'cslang'), __('Set up the message that will appear when the required field is empty', 'cslang'))); ?>
                                                            </div>
                                                        </div>
                                                        <div class="row small-content">
                                                            <span class="col-md-3"><?php esc_attr_e('Confirmation messages', 'cslang'); ?></span>
                                                            <div class="col-md-8">
                                                                <input type="text" class="col-md-11" name="alert_confirmation_messages" value="<?php echo esc_attr($formData['confirmationMsg']); ?>" required>&nbsp;
                                                                <?php echo esc_html(CS_Page_Home::get_narration_script(__('Confirmation messages', 'cslang'), __('Set up the message that will appear when the form submitted', 'cslang'))); ?>
                                                            </div>
                                                        </div>
                                                        <div class="row small-content" style="margin-top: 30px;">
                                                            <div class="col-md-3">
                                                                <button class="btn btn-primary"><?php esc_attr_e('Save', 'cslang'); ?></button>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div> <!-- End Confirmation message form-->
                        </form>
                    </div>
                    <script>
                        jQuery(document).ready(function() {
                            jQuery('#csadd_to_form_btn').click(function() {
                                return false;
                            });
                        });
                    </script>
                <?php
                } else {
                    // If empty?
                ?>
                    <div id="main-content" class="cs-content">
                        <div class="panel panel-default row small-content">
                            <!--						<div class="page-header">
                                                                                    <strong><?php esc_attr_e('Subscription form', 'cslang'); ?></strong>
                                                                            </div>-->
                            <div style="padding: 24px 32px; margin-bottom: 12px;">
                                <?php esc_attr_e('Sorry, you selected invalid form ID. Please check again if the ID is right.', 'cslang'); ?>
                            </div>
                        </div>
                    </div>
            <?php
                }
            }
        }
        /** Generate welcome page */
        function generate_welcome_page()
        {
            ?>
            <div id="main-content" class="row">
                <img class="small-content" src="<?php echo esc_url(CS_Manager::$plugin_url . '/img/background/setting.png'); ?>" style="width: 100%;">
            </div>
<?php
            CS_Page_Home::print_disable_popup();
        }
        /** Save subscription form setting */
        public static function save_setting_subscription()
        {
            if (!current_user_can('manage_options')) {
                wp_die('Not allowed');
            }
            // Check secret through hidden referrer field.
            check_admin_referer('cssetting_subscription');
            // Subscription form.
            $formID         = isset($_POST['csform_id']) ? sanitize_text_field($_POST['csform_id']) : '';
            $form_name         = isset($_POST['csform_name']) ? sanitize_text_field($_POST['csform_name']) : '';
            $form_html         = isset($_POST['csform_html']) ? stripslashes($_POST['csform_html']) : '';
            $list_ids         = isset($_POST['list_id']) ? maybe_serialize($_POST['list_id']) : '';
            $moduleID         = isset($_POST['moduleID']) ? maybe_serialize($_POST['moduleID']) : '';
            $dependTheme     = isset($_POST['cscss_type']) ? sanitize_text_field($_POST['cscss_type']) : '';
            $customCss         = isset($_POST['csform_css']) ? $_POST['csform_css'] : '';
            $gCaptcha         = isset($_POST['csadd_captcha']) ? sanitize_text_field($_POST['csadd_captcha']) : '0';
            $gCaptchaSecret = isset($_POST['cscaptcha_secret']) ? sanitize_text_field($_POST['cscaptcha_secret']) : '';
            $gCaptchaSite     = isset($_POST['cscaptcha_site']) ? sanitize_text_field($_POST['cscaptcha_site']) : '';
            $termAccept     = isset($_POST['csadd_terms']) ? sanitize_text_field($_POST['csadd_terms']) : '0';
            $termURL         = isset($_POST['csterms_url']) ? sanitize_text_field($_POST['csterms_url']) : '';
            $gCaptchaType     = isset($_POST['csrecaptcha_type']) ? sanitize_text_field($_POST['csrecaptcha_type']) : '0';
            if ($gCaptcha != '0') {
                if ($gCaptchaType == '0') {
                    $gCaptcha = '3';  // google recaptcha.
                } elseif ($gCaptchaType == '1') {
                    $gCaptcha = '2';   // google invisible recaptcha.
                }
            }
            // for wpml plugins.
            $pid = isset($_POST['pid']) ? sanitize_text_field($_POST['pid']) : '';
            $lang = isset($_POST['lang']) ? sanitize_text_field($_POST['lang']) : '';
            // sign up process.
            $templateID = '-1';
            $confirmID = '-1';
            $redirectInForm = '';
            $isOpt = isset($_POST['is_confirm_email']) ? sanitize_text_field($_POST['is_confirm_email']) : false;
            if ($isOpt) {
                $templateID = isset($_POST['template_id']) ? sanitize_text_field($_POST['template_id']) : '-1';
            }
            $isDopt   = isset($_POST['is_double_optin']) ? sanitize_text_field($_POST['is_double_optin']) : false;
            $emailDopt = '';
            $datetimeDopt = '';
            if ($isDopt) {
                $templateID   = isset($_POST['doubleoptin_template_id']) ? sanitize_text_field($_POST['doubleoptin_template_id']) : '-1';
                $confirmID    = isset($_POST['confirm_template_id']) ? sanitize_text_field($_POST['confirm_template_id']) : '-1';
                $emailDopt    = isset($_POST['is_email_double_optin']) ? sanitize_text_field($_POST['is_email_double_optin']) : '';
                $datetimeDopt = isset($_POST['is_datetime_double_optin']) ? sanitize_text_field($_POST['is_datetime_double_optin']) : '';
            }
            $redirectInEmail = isset($_POST['redirect_url']) ? sanitize_text_field($_POST['redirect_url']) : '';
            $isRedirectInForm = isset($_POST['is_redirect_url_click']) ? sanitize_text_field($_POST['is_redirect_url_click']) : false;
            if ($isRedirectInForm) {
                $redirectInForm = isset($_POST['redirect_url_click']) ? sanitize_text_field($_POST['redirect_url_click']) : '';
            }
            $isDataEmailsSpecific = isset($_POST['is_data_emails_specific_click']) ? sanitize_text_field($_POST['is_data_emails_specific_click']) : false;
            if ($isDataEmailsSpecific) {
                $emailSpecificId      = isset($_POST['data_specific_emails']) ? sanitize_text_field($_POST['data_specific_emails']) : '';
            }
            // get available attributes list.
            $attributes = CS_API_Manager::get_attributes($moduleID);
            $attributes = array_merge($attributes['attributes']['normal_attributes'], $attributes['attributes']['category_attributes']);
            // print "$attributes = " . print_r($attributes); //TODO to comment
            $attributes_type = array();
            $available_attrs = array();
            if (isset($attributes) && is_array($attributes)) {
                foreach ($attributes as $attribute) {
                    $pos = strpos($form_html, 'cs-' . $attribute['Name'] . '-area');
                    if (false !== $pos) {
                        $available_attrs[] = $attribute['Name'];
                        $attributes_type[$attribute['Name']] = $attribute['DataType'];
                    }
                }
            }
            //var_dump($attributes_type); //TODO to comment
            $successMsg      = isset($_POST['alert_success_message']) ? sanitize_text_field(esc_attr($_POST['alert_success_message'])) : '';
            $errorMsg          = isset($_POST['alert_error_message']) ? sanitize_text_field(esc_attr($_POST['alert_error_message'])) : '';
            $existMsg          = isset($_POST['alert_exist_subscriber']) ? sanitize_text_field(esc_attr($_POST['alert_exist_subscriber'])) : '';
            $invalidMsg      = isset($_POST['alert_invalid_email']) ? sanitize_text_field(esc_attr($_POST['alert_invalid_email'])) : '';
            $requiredMsg      = isset($_POST['alert_required_message']) ? sanitize_text_field(esc_attr($_POST['alert_required_message'])) : '';
            $confirmationMsg = isset($_POST['alert_confirmation_messages']) ? sanitize_text_field(esc_attr($_POST['alert_confirmation_messages'])) : '';
            $formData = array(
                'title'          => $form_name,
                'html'              => addslashes($form_html),
                'css'             => $customCss,
                'listID'          => $list_ids,
                'dependTheme'      => $dependTheme,
                'isOpt'          => $isOpt,
                'isDopt'          => $isDopt,
                'emailDopt'      => $emailDopt,
                'datetimeDopt'   => $datetimeDopt,
                'templateID'      => $templateID,
                'moduleID'          => $moduleID,
                'confirmID'      => $confirmID,
                'isEmailSpecific' => $isDataEmailsSpecific,
                'emailSpecificId' => $emailSpecificId,
                'redirectInEmail' => $redirectInEmail,
                'redirectInForm' => $redirectInForm,
                'successMsg'      => $successMsg,
                'errorMsg'          => $errorMsg,
                'existMsg'          => $existMsg,
                'invalidMsg'      => $invalidMsg,
                'requiredMsg'      => $requiredMsg,
                'confirmationMsg' => $confirmationMsg,
                'attributes'     => implode(',', $available_attrs),
                'attributes_type' => serialize($attributes_type),
                'gcaptcha'       => $gCaptcha,
                'gcaptcha_secret' => $gCaptchaSecret,
                'gcaptcha_site'  => $gCaptchaSite,
                'termAccept'     => $termAccept,
                'termsURL'       => $termURL,
            );
            if ('new' === $formID || 'duplicate' === $formID) {
                $cirrus = new Cirrus(CS_Manager::CIRRUSSHIELD_API_URL, CS_Manager::$username, CS_Manager::$password);
                $token    = $cirrus->get_access_tokens();
                //var_dump($token); // TODO to comment
                $module   = $cirrus->get_module($moduleID, $token);
                //var_dump($moduleID); // TODO to comment
                if ('new' === $formID) {
                    $formData = CS_Forms::getDefaultForm($moduleID);
                    $formData['moduleID'] = $moduleID;
                    $formData['title'] = str_replace("'"," ",$module['Label']) . ' Form';
                }
                //var_dump($formData); // TODO to comment
                $formID = CS_Forms::addForm($formData);
                //var_dump($formID); // TODO to comment
                //exit(); // TODO to comment
                if ('' !== $pid) {
                    $transID = CS_Forms_Lang::add_form_ID($formID, $pid, $lang);
                }
            } else {
                CS_Forms::updateForm($formID, $formData);
            }
            if ('' !== $pid) {
                wp_safe_redirect(
                    add_query_arg(
                        array(
                            'page' => self::PAGE_ID,
                            'action' => 'edit',
                            'id' => $formID,
                            'pid' => $pid,
                            'lang' => $lang,
                        ),
                        admin_url('admin.php')
                    )
                );
                exit();
            } else {
                wp_safe_redirect(
                    add_query_arg(
                        array(
                            'page' => self::PAGE_ID,
                            'action' => 'edit',
                            'id' => $formID,
                        ),
                        admin_url('admin.php')
                    )
                );
                exit();
            }
        }
        /**
         * Get template lists of cirrusshield
         */
        public static function get_template_lists()
        {
            $cirrus = new Cirrus(CS_Manager::CIRRUSSHIELD_API_URL, CS_Manager::$username, CS_Manager::$password);
            $data = array(
                'type' => 'template',
                'status' => 'temp_active',
            );
            $response = $cirrus->get_campaigns_v2($data);
            if (!isset($response['code']) || ('success' !== $response['code'])) {
                return null;
            }
            return $response['data']['campaign_records'];
        }
        /** Ajax process when change template id */
        public static function ajax_change_template()
        {
            check_ajax_referer('ajax_csadmin_nonce', 'security');
            $template_id = isset($_POST['template_id']) ? sanitize_text_field($_POST['template_id']) : '';
            $cirrus = new Cirrus(CS_Manager::CIRRUSSHIELD_API_URL, CS_Manager::$username, CS_Manager::$password);
            $data = array(
                'id' => $template_id,
            );
            $response = $cirrus->get_campaign_v2($data);
            $ret_email = '-1';
            if ('success' == $response['code']) {
                $from_email = $response['data'][0]['from_email'];
                if ('[DEFAULT_FROM_EMAIL]' == $from_email) {
                    $ret_email = '-1';
                } else {
                    $ret_email = $from_email;
                }
            }
            wp_send_json($ret_email);
        }
        /**
         * Ajax module to get all lists.
         */
        public static function ajax_get_lists()
        {
            check_ajax_referer('ajax_csadmin_nonce', 'security');
            $lists = CS_API_Manager::get_lists();
            $frmID = isset($_POST['frmid']) ? sanitize_text_field($_POST['frmid']) : '';
            $formData = CS_Forms::getForm($frmID);
            $result = array(
                'lists' => $lists,
                'selected' => $formData['listID'],
            );
            wp_send_json($result);
        }
        /**
         * Ajax module to get all templates.
         */
        public static function ajax_get_templates()
        {
            check_ajax_referer('ajax_csadmin_nonce', 'security');
            $templates = CS_API_Manager::get_templates();
            $result = array(
                'templates' => $templates,
            );
            wp_send_json($result);
        }
        /**
         * Ajax module to get all attributes.
         */
        public static function ajax_get_attributes()
        {
            check_ajax_referer('ajax_csadmin_nonce', 'security');
            $attrs = CS_API_Manager::get_attributes($_POST['moduleID']);
            $result = array(
                'attrs' => $attrs,
            );
            wp_send_json($result);
        }
        /**
         * Ajax module to update form html for preview
         */
        public static function ajax_update_html()
        {
            check_ajax_referer('ajax_csadmin_nonce', 'security');
            $gCaptchaType = isset($_POST['gCaptchaType']) ? $_POST['gCaptchaType'] : '1';
            $gCaptcha = isset($_POST['gCaptcha']) ? $_POST['gCaptcha'] : '0';
            if ($gCaptcha != '0') {
                if ($gCaptchaType == '1') {
                    $gCaptcha = '2';
                } elseif ($gCaptchaType == '0') {
                    $gCaptcha = '3';
                }
            }
            $formData = array(
                'html' => isset($_POST['frmData']) ? $_POST['frmData'] : '',
                'css' => isset($_POST['frmCss']) ? $_POST['frmCss'] : '',
                'dependTheme' => isset($_POST['isDepend']) ? $_POST['isDepend'] : '',
                'gCaptcha' => $gCaptcha,
                'gCaptcha_site' => isset($_POST['gCaptchaSite']) ? $_POST['gCaptchaSite'] : ''
            );
            update_option(CS_Manager::PREVIEW_OPTION_NAME, $formData);
            die;
        }
        /**
         * Ajax module to copy content from origin form for translation
         */
        public static function ajax_copy_origin_form()
        {
            check_ajax_referer('ajax_csadmin_nonce', 'security');
            $pID = isset($_POST['pid']) ? sanitize_text_field($_POST['pid']) : 1;
            $formData = CS_Forms::getForm($pID);
            $html = $formData['html'];
            wp_send_json($html);
        }
    }
}
