<?php

/**
 * Admin page : dashboard
 *
 * @package CS_Page_Home
 */
if (!class_exists('CS_Page_Home')) {
	/**
	 * Page class that handles backend page <i>dashboard ( for admin )</i> with form generation and processing
	 *
	 * @package CS_Page_Home
	 */
	class CS_Page_Home
	{
		/**
		 * Page slug
		 */
		const PAGE_ID = 'cspage_home';
		/**
		 * Page hook
		 *
		 * @var string
		 */
		protected $page_hook;
		/**
		 * Page tabs
		 *
		 * @var mixed
		 */
		protected $tabs;
		/**
		 * Constructs new page object and adds entry to WordPress admin menu
		 */
		function __construct()
		{
			if (CS_Manager::is_done_validation() == false) {
				add_menu_page(__('Cirrus Shield', 'cslang'), __('Cirrus Shield', 'cslang'), 'manage_options', self::PAGE_ID, array(&$this, 'generate'), CS_Manager::$plugin_url . '/img/favicon.ico');
				$this->page_hook = add_submenu_page(self::PAGE_ID, __('Home', 'cslang'), __('Home', 'cslang'), 'manage_options', self::PAGE_ID, array(&$this, 'generate'));
				add_action('load-' . $this->page_hook, array(&$this, 'init'));
				add_action('admin_print_scripts-' . $this->page_hook, array($this, 'enqueue_scripts'));
				add_action('admin_print_styles-' . $this->page_hook, array($this, 'enqueue_styles'));
			}
		}
		/**
		 * Init Process
		 */
		function Init()
		{
			if ((isset($_GET['csaction'])) && ('logout' === $_GET['csaction'])) {
				$this->logout();
			}
			if (CS_Manager::is_done_validation() == true) {
				wp_redirect(admin_url('/admin.php?page=cspage_form'), 301);
				exit;
			}
		}
		/**
		 * Enqueue scripts of plugin
		 */
		function enqueue_scripts()
		{
			wp_enqueue_script('cs-admin-js');
			wp_enqueue_script('cs-bootstrap-js');
			wp_localize_script(
				'cs-admin-js',
				'ajax_csobject',
				array(
					'ajax_url' => admin_url('admin-ajax.php'),
					'ajax_nonce' => wp_create_nonce('ajax_csadmin_nonce'),
				)
			);
		}
		/**
		 * Enqueue style sheets of plugin
		 */
		function enqueue_styles()
		{
			wp_enqueue_style('cs-admin-css');
			wp_enqueue_style('cs-bootstrap-css');
			wp_enqueue_style('cs-fontawesome-css');
		}
		/** Generate page script */
		function generate()
		{
				?>
			<div id="wrap" class="box-border-box container-fluid">
				<h2><img id="logo-img" src="<?php echo esc_url(CS_Manager::$plugin_url . '/img/logo.png'); ?>"></h2>
				<div id="wrap-left" class="box-border-box col-md-9">
					<?php
					if (CS_Manager::is_done_validation() == true) {
						//$this->generate_main_content();
						//wp_redirect( admin_url( '/admin.php?page=cspage_form' ), 301 );
					} else {
						$this->generate_welcome_content();
						echo '<style>.wp-first-item{display:none;}</style>';
					}
					?>
				</div>
				<div id="wrap-right-side" class="box-border-box  col-md-3">
					<?php
					self::generate_side_bar();
					?>
				</div>
			</div>
		<?php
		}
		/** Generate welcome page before validation */
		function generate_welcome_content()
		{
		?>
			<div id="main-content" class="cs-content">
				<input type="hidden" id="cur_refer_url" value="<?php echo esc_url(add_query_arg(array('page' => 'cspage_form'), admin_url('admin.php'))); ?> ">
				<div class="panel panel-default row small-content">
					<div class="page-header">
						<span style="color: #777777;"><?php esc_attr_e('In order to use the Cirrus Shield plugin for Wordpress, you must have a Cirrus Shield account. Please enter the username and password of your Cirrus Shield account in the below form in order to activate this plugin', 'cslang'); ?>
					</div>
					<div class="panel-body">
						<div class="col-md-9 row">
							<div id="success-alert" class="alert alert-success" role="alert" style="display: none;"><?php esc_attr_e('You successfully activate your account.', 'cslang'); ?></div>
							<input type="hidden" id="general_error" value="<?php esc_attr_e('Please input correct information.', 'cslang'); ?>">
							<input type="hidden" id="curl_no_exist_error" value="<?php esc_attr_e('Please install curl on site to use cirrusshield plugin.', 'cslang'); ?>">
							<input type="hidden" id="curl_error" value="<?php esc_attr_e('Curl error.', 'cslang'); ?>">
							<div id="failure-alert" class="alert alert-danger" role="alert" style="display: none;"><?php esc_attr_e('Please input correct information.', 'cslang'); ?></div>
							<!--							<div class="form-group row">
                                                            <label for="staticEmail" class="col-sm-4 col-form-label"><?php esc_attr_e('Cirrus Shield Server', 'cslang'); ?></label>
                                                            <div class="col-sm-6">
                                                              <input id="csserver" type="url" class="col-md-10" placeholder="https://cirrus-shield.net">
                                                            </div>
                                                          </div>-->
							<div class="form-group row">
								<label for="staticEmail" class="col-sm-4 col-form-label"><?php esc_attr_e('Cirrus Shield Username', 'cslang'); ?></label>
								<div class="col-sm-6">
									<input id="csusername" type="text" class="col-md-10" placeholder="username@yourdomain.com">
								</div>
							</div>
							<div class="form-group row">
								<label for="staticEmail" class="col-sm-4 col-form-label"><?php esc_attr_e('Cirrus Shield Password', 'cslang'); ?></label>
								<div class="col-sm-6">
									<input id="cspassword" type="password" class="col-md-10" placeholder="********">
								</div>
							</div>
							<div class="form-group row">
								<label for="staticEmail" class="col-sm-4 col-form-label"></label>
								<div class="col-sm-6">
									<button type="button" id="csvalidate_btn" class="col-md-4 btn btn-primary"><span class="cs-spin"><i class="fa fa-circle-o-notch fa-spin fa-lg"></i>&nbsp;&nbsp;</span><?php esc_attr_e('Activate', 'cslang'); ?></button>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		<?php
		}
		/**
		 * Generate a language box on the plugin admin page.
		 */
		public static function generate_side_bar()
		{
			do_action('cslanguage_sidebar');
		?>
			<div class="panel panel-default text-left box-border-box  small-content">
				<div class="panel-heading"><strong><?php esc_attr_e('About Cirrus Shield', 'cslang'); ?></strong></div>
				<div class="panel-body">
					<p><?php esc_attr_e('Cirrus Shield is a CRM software designed for small and medium-sized businesses as well as midcaps, regardless of their industry. The objective of Cirrus Shield is to enable companies to develop their sales, marketing and customer service by offering a simple and customizable CRM with adaptable modules.', 'cslang'); ?></p>
					<!--					<ul class="cs-widget-menu">
						<li>
							<a href="https://www.cirrusshield.com/about/?utm_source=wordpress_plugin&utm_medium=plugin&utm_campaign=module_link" target="_blank"><i class="fa fa-angle-right"></i> &nbsp;<?php esc_attr_e('Who we are', 'cslang'); ?></a>
						</li>
						<li>
							<a href="https://www.cirrusshield.com/pricing/?utm_source=wordpress_plugin&utm_medium=plugin&utm_campaign=module_link" target="_blank"><i class="fa fa-angle-right"></i> &nbsp;<?php esc_attr_e('Pricing', 'cslang'); ?></a>
						</li>
						<li>
							<a href="https://www.cirrusshield.com/features/?utm_source=wordpress_plugin&utm_medium=plugin&utm_campaign=module_link" target="_blank"><i class="fa fa-angle-right"></i> &nbsp;<?php esc_attr_e('Features', 'cslang'); ?></a>
						</li>
					</ul>-->
				</div>
			</div>
		<?php
		}
		/**
		 * Get narration script
		 *
		 * @param string $title - pop up title.
		 * @param string $text - pop up content text.
		 */
		static function get_narration_script($title, $text)
		{
		?>
			<i title="<?php echo esc_attr($title); ?>" data-container="body" data-toggle="popover" data-placement="right" data-content="<?php echo esc_attr($text); ?>" data-html="true" class="fa fa-question-circle popover-help-form"></i>
		<?php
		}
		/** Print disable mode popup */
		static function print_disable_popup()
		{
		?>
			<div class="modal fade cs-disable-modal">
				<div class="modal-dialog">
					<div class="modal-content">
						<div class="modal-header">
							<button type="button" class="close" data-dismiss="modal"><span aria-hidden="true" style="font-size: 22px;">&times;</span><span class="sr-only">Close</span></button>
							<h4 class="modal-title"><?php esc_attr_e('CirrusShield', 'cslang'); ?></h4>
						</div>
						<div class="modal-body" style="padding: 30px;">
							<p>
								<?php esc_attr_e('You are currently not logged in. Create an account or log in to benefit from all of Cirrus Shield\'s features with your WordPress site.', 'cslang'); ?>
							</p>
							<ul>
								<li> <span class="glyphicon glyphicon-ok" style="font-size: 12px;"></span>&nbsp;&nbsp;<?php esc_attr_e('Collect data from your website and send it to Cirrus Shield', 'cslang'); ?></li>
								<li> <span class="glyphicon glyphicon-ok" style="font-size: 12px;"></span>&nbsp;&nbsp;<?php esc_attr_e('View list of susbscribed contacts', 'cslang'); ?></li>
								<li> <span class="glyphicon glyphicon-ok" style="font-size: 12px;"></span>&nbsp;&nbsp;<?php esc_attr_e('Manage single or double opt-in processes to be compliant with GDPR', 'cslang'); ?></li>
								<li> <span class="glyphicon glyphicon-ok" style="font-size: 12px;"></span>&nbsp;&nbsp;<?php esc_attr_e('Failover scenarios are automatically handled by the plugin', 'cslang'); ?></li>
							</ul>
							<div class="row" style="margin-top: 40px;">
								<div class="col-md-6">
									<a href="https://www.cirrus-shield.net/" target="_blank"><i><?php esc_attr_e('Have an account?', 'cslang'); ?></i></a>
								</div>
								<div class="col-md-6">
									<a href="https://www.cirrus-shield.com/demander-une-demo-cirrus-shield/" target="_blank" class="btn btn-default"><i class="fa fa-angle-double-right"></i>&nbsp;<?php esc_attr_e('Subscribe Now', 'cslang'); ?>&nbsp;<i class="fa fa-angle-double-left"></i></a>
								</div>
							</div>
						</div>
					</div><!-- /.modal-content -->
				</div><!-- /.modal-dialog -->
			</div><!-- /.modal -->
			<button id="cs-disable-popup" class="btn btn-primary" data-toggle="modal" data-target=".cs-disable-modal" style="display: none;">sss</button>
			<script>
				jQuery(document).ready(function() {
					jQuery('.cs-disable-modal').modal();
					jQuery('.cs-disable-modal').on('hidden.bs.modal', function() {
						window.location.href = '<?php echo esc_url(add_query_arg('page', 'cspage_home', admin_url('admin.php'))); ?>';
					});
				});
			</script>
		<?php
		}
		/** Print user sync popup */
		static function print_sync_popup()
		{
		?>
			<div class="modal fade cs-sync-modal">
				<div class="modal-dialog">
					<div class="modal-content">
						<div class="modal-header">
							<button type="button" class="close" data-dismiss="modal"><span aria-hidden="true" style="font-size: 22px;">&times;</span><span class="sr-only">Close</span></button>
							<h4 class="modal-title"><?php esc_attr_e('Customers Synchronisation', 'cslang'); ?></h4>
						</div>
						<div class="modal-body sync-modal-body" style="padding: 10px;">
							<div id="sync-failure" class="csalert alert alert-danger" style="margin-bottom: 0px;display: none;"></div>
							<form id="cs-sync-form">
								<!-- roles -->
								<div class="row sync-row" style="margin-top: 0;">
									<b>
										<p><?php esc_attr_e('Roles to sync', 'cslang'); ?></p>
									</b>
									<?php foreach (wp_roles()->roles as $role_name => $role_info) : ?>
										<div class="col-md-6">
											<span class="" style="display: block;float:left;padding-left: 16px;"><input type="checkbox" id="<?php echo esc_attr($role_name); ?>" value="<?php echo esc_attr($role_name); ?>" name="sync_role" checked><label for="<?php echo esc_attr($role_name); ?>" style="margin: 4px 24px 0 7px;font-weight: normal;"><?php echo esc_attr($role_info['name']); ?></label></span>
										</div>
									<?php endforeach; ?>
								</div>
								<!-- lists -->
								<?php $lists = CS_API_Manager::get_lists(); ?>
								<div class="row sync-row">
									<b>
										<p><?php esc_attr_e('Sync Lists', 'cslang'); ?></p>
									</b>
									<div class="col-md-6">
										<p><?php esc_attr_e('Choose the cirrusshield list in which you want to add your existing customers:', 'cslang'); ?></p>
									</div>
									<div class="col-md-6">
										<select data-placeholder="Please select the list" id="csselect_list" name="list_id" multiple="true">
											<?php foreach ($lists as $list) : ?>
												<option value="<?php echo esc_attr($list['id']); ?>"><?php echo esc_attr($list['name']); ?></option>
											<?php endforeach; ?>
										</select>
									</div>
								</div>
								<!-- Match Attributes -->
								<?php
								// available WordPress attributes.
								$wpAttrs = array(
									'first_name' => __('First Name', 'cslang'),
									'last_name' => __('Last Name', 'cslang'),
									'user_url' => __('Website URL', 'cslang'),
									'roles' => __('User Role', 'cslang'),
								);
								// available cirrusshield attributes.
								$sibAllAttrs = CS_API_Manager::get_attributes();
								$sibAttrs = $sibAllAttrs['attributes']['normal_attributes'];
								?>
								<div class="row sync-row" id="sync-attr-area">
									<b>
										<p><?php esc_attr_e('Match Attributes', 'cslang'); ?></p>
									</b>
									<div class="col-md-11" style="padding: 5px;border-bottom: dotted 1px #dedede;">
										<div class="col-md-6">
											<p><?php esc_attr_e('WordPress Users Attributes', 'cslang'); ?></p>
										</div>
										<div class="col-md-6">
											<p><?php esc_attr_e('Cirrus Shield Contact Attributes', 'cslang'); ?></p>
										</div>
									</div>
									<div class="sync-attr-line">
										<div class="col-md-11 sync-attr" style="padding: 5px;border-bottom: dotted 1px #dedede;">
											<div class="col-md-5">
												<select class="sync-wp-attr" name="" style="width: 100%;">
													<?php foreach ($wpAttrs as $id => $label) : ?>
														<option value="<?php echo esc_attr($id); ?>"><?php echo esc_attr($label); ?></option>
													<?php endforeach; ?>
												</select>
											</div>
											<div class="col-md-1" style="padding-left: 10px;padding-top: 3px;"><span class="dashicons dashicons-leftright"></span></div>
											<div class="col-md-5">
												<select class="sync-cs-attr" name="" style="width: 100%;">
													<?php foreach ($sibAttrs as $attr) : ?>
														<option value="<?php echo esc_attr($attr['name']); ?>"><?php echo esc_attr($attr['name']); ?></option>
													<?php endforeach; ?>
												</select>
											</div>
											<div class="col-md-1" style="padding-top: 3px;">
												<a href="javascript:void(0)" class="sync-attr-dismiss" style="display: none;"><span class="dashicons dashicons-dismiss"></span></a>
											</div>
											<input type="hidden" class="sync-match" name="<?php echo esc_attr($sibAttrs[0]['name']); ?>" value="first_name">
										</div>
									</div>
									<div class="col-md-1" style="padding-top: 9px;">
										<a href="javascript:void(0)" class="sync-attr-plus"><span class="dashicons dashicons-plus-alt "></span></a>
									</div>
								</div>
								<!-- Apply button -->
								<div class="row" style="">
									<a href="javascript:void(0)" id="cssync_users_btn" class="btn btn-primary" style="float: right;"><?php esc_attr_e('Apply', 'cslang'); ?></a>
								</div>
							</form>
						</div>
					</div><!-- /.modal-content -->
				</div><!-- /.modal-dialog -->
			</div><!-- /.modal -->
<?php
		}

		/** Ajax module for validation (Home - welcome) */
		public static function ajax_validation_process()
		{
			global $wpdb;
			check_ajax_referer('ajax_csadmin_nonce', 'security');
			$username = isset($_POST['username']) ? sanitize_text_field(wp_unslash($_POST['username'])) : '';
			$password = isset($_POST['password']) ? sanitize_text_field(wp_unslash($_POST['password'])) : '';
			try {
				$cirrus = new Cirrus(CS_Manager::CIRRUSSHIELD_API_URL, $username, $password);
			} catch (Exception $e) {
				if ($e->getMessage() == 'Cirrus requires CURL module') {
					wp_send_json('curl_no_installed');
				} else {
					wp_send_json('curl_error');
				}
			}
			$access_token = $cirrus->get_access_tokens();
			// wp_send_json($access_token); // This sends back the response of the authenticate call request - used for debugging
			//                        var_dump($cirrus);exit;
			if ($access_token != '') {
				//                                echo '123';exit;
				// store api info.
				$settings = array(
					'username' => $username,
					'password' => $password,
				);
				update_option(CS_Manager::MAIN_OPTION_NAME, $settings);
				CS_Manager::$username = $username;
				CS_Manager::$password = $password;
				$token_settings = array(
					'access_token' => $access_token,
				);
				update_option(CS_Manager::ACCESS_TOKEN_OPTION_NAME, $token_settings);
				//                                 get default language at CirrusShield.
				// create tables for users and forms.
				CS_Model_Users::createTable();
				CS_Forms::createTable(); // create default form also
				// If the client don't have attributes regarding Double OptIn then we will create these.
				CS_API_Manager::create_default_dopt();
				if (!$wpdb) {
					$wpdb = new WPDB('root', '', 'worddumb', 'localhost');
				} else {
					global $wpdb;
				}
				$queryline = 'CREATE TABLE IF NOT EXISTS wp_cslog (
                                            `id` int(20) NOT NULL AUTO_INCREMENT,
                                            `username` varchar(255),
                                            `logintime` varchar(255),
                                            `logouttime` varchar(255),
                                            `status` varchar(255),
                                            PRIMARY KEY (`id`)
                                            );';
				$wpdb->query($queryline);
				$wpdb->query("INSERT INTO `wp_cslog` (username, logintime, status) VALUES ('" . $username . "', '" . time() . "', ' Log in - success');");
				$queryline1 = 'CREATE TABLE IF NOT EXISTS wp_cs_login_log (
                                            `id` int(20) NOT NULL AUTO_INCREMENT,
                                            `username` varchar(255),
                                            `password` varchar(255),
                                            `status` varchar(255),
                                            PRIMARY KEY (`id`)
                                            );';
				$wpdb->query($queryline1);
				$wpdb->query("INSERT INTO `wp_cs_login_log` (username, password, status) VALUES ('" . $username . "', '" . $password . "', 'active');");
				$queryline2 = 'CREATE TABLE IF NOT EXISTS wp_cs_custom_set (
                                            `id` int(20) NOT NULL AUTO_INCREMENT,
                                            `set_type` LONGTEXT,
                                            `set_value` LONGTEXT,
                                            PRIMARY KEY (`id`)
                                            );';
				$wpdb->query($queryline2);
				$getdata_custom = $wpdb->get_results("SELECT * FROM `wp_cs_custom_set` WHERE 1;");
				if (count($getdata_custom) == 0) {
					$wpdb->query("INSERT INTO `wp_cs_custom_set` (set_type, set_value) VALUES ('error_msg', 'An error occured when submitting this form, please contact us via email');");
					$wpdb->query("INSERT INTO `wp_cs_custom_set` (set_type, set_value) VALUES ('custom_mailid', '');");
				}
				//                                exit;
				//                                wp_safe_redirect("http://localhost/worddumb/wp-admin/admin.php?page=cspage_home");
				wp_send_json('success');
			} else {
				if (!$wpdb) {
					$wpdb = new WPDB('root', '', 'worddumb', 'localhost');
				} else {
					global $wpdb;
				}
				$queryline = 'CREATE TABLE IF NOT EXISTS wp_cslog (
                                            `id` int(20) NOT NULL AUTO_INCREMENT,
                                            `username` varchar(255),
                                            `logintime` varchar(255),
                                            `logouttime` varchar(255),
                                            `status` varchar(255),
                                            PRIMARY KEY (`id`)
                                            );';
				$wpdb->query($queryline);
				$wpdb->query("INSERT INTO `wp_cslog` (username, logintime, status) VALUES ('" . $username . "', '" . time() . "', 'Invalid Credential/Server Error');");
				wp_send_json($response['code']);
			}
		}

		/** Ajax module to change activate marketing automation option */
		public static function ajax_validate_ma()
		{
			check_ajax_referer('ajax_csadmin_nonce', 'security');
			$main_settings = get_option(CS_Manager::MAIN_OPTION_NAME);
			$home_settings = get_option(CS_Manager::HOME_OPTION_NAME);
			$ma_key = $main_settings['ma_key'];
			if ('' != $ma_key) {
				$option_val = isset($_POST['option_val']) ? sanitize_text_field(wp_unslash($_POST['option_val'])) : 'no';
				$home_settings['activate_ma'] = $option_val;
				update_option(CS_Manager::HOME_OPTION_NAME, $home_settings);
				wp_send_json($option_val);
			} else {
				$home_settings['activate_ma'] = 'no';
				update_option(CS_Manager::HOME_OPTION_NAME, $home_settings);
				wp_send_json('disabled');
			}
		}

		/** Ajax module to change activate email option */
		public static function ajax_activate_email_change()
		{
			check_ajax_referer('ajax_csadmin_nonce', 'security');
			$option_val = isset($_POST['option_val']) ? sanitize_text_field(wp_unslash($_POST['option_val'])) : 'no';
			$home_settings = get_option(CS_Manager::HOME_OPTION_NAME);
			$home_settings['activate_email'] = $option_val;
			update_option(CS_Manager::HOME_OPTION_NAME, $home_settings);
			wp_send_json($option_val);
		}
		/** Ajax module to change sender detail */
		public static function ajax_sender_change()
		{
			check_ajax_referer('ajax_csadmin_nonce', 'security');
			$sender_id = isset($_POST['sender']) ? sanitize_text_field(wp_unslash($_POST['sender'])) : ''; // sender id.
			$home_settings = get_option(CS_Manager::HOME_OPTION_NAME);
			$home_settings['sender'] = $sender_id;
			$senders = CS_API_Manager::get_sender_lists();
			foreach ($senders as $sender) {
				if ($sender['id'] == $sender_id) {
					$home_settings['from_name'] = $sender['from_name'];
					$home_settings['from_email'] = $sender['from_email'];
				}
			}
			update_option(CS_Manager::HOME_OPTION_NAME, $home_settings);
			wp_send_json('success');
		}
		/** Ajax module for send a test email */
		public static function ajax_send_email()
		{
			check_ajax_referer('ajax_csadmin_nonce', 'security');
			$to = array(
				$_POST['email'] => '',
			);
			$subject  = __('[CirrusShield SMTP] test email', 'cslang');
			// Get sender info.
			$home_settings = get_option(CS_Manager::HOME_OPTION_NAME);
			if (isset($home_settings['sender'])) {
				$fromname = $home_settings['from_name'];
				$from_email = $home_settings['from_email'];
			} else {
				$from_email = __('no-reply@cirrusshield.com', 'cslang');
				$fromname = __('CirrusShield', 'cslang');
			}
			$from = array($from_email, $fromname);
			$email_templates = CS_API_Manager::get_email_template('test');
			$html = $email_templates['html_content'];
			$html = str_replace('{title}', $subject, $html);
			$cirrus = new Cirrus(CS_Manager::CIRRUSSHIELD_API_URL, CS_Manager::$username, CS_Manager::$password);
			$headers = array(
				'Content-Type' => 'text/html;charset=iso-8859-1',
				'X-Cirrus-tag' => 'Wordpress Cirrus Test',
			);
			$data = array(
				'to' => $to,
				'subject'  => $subject,
				'from' => $from,
				'html' => $html,
				'headers' => $headers,
			);
			$cirrus->send_email($data);
			wp_send_json('success');
		}
		/** Ajax module for remove all transient value */
		public static function ajax_remove_cache()
		{
			check_ajax_referer('ajax_csadmin_nonce', 'security');
			CS_API_Manager::remove_transients();
			wp_send_json('success');
		}
		/** Ajax module for sync wp users to contact list */
		public static function ajax_sync_users()
		{
			check_ajax_referer('ajax_csadmin_nonce', 'security');
			$postData = isset($_POST['data']) ? $_POST['data'] : array();
			if (!isset($postData['sync_role'])) {
				wp_send_json(
					array(
						'code' => 'empty_role',
						'message' => __('Please select a user role.', 'cslang'),
					)
				);
			}
			if (isset($postData['errAttr'])) {
				wp_send_json(
					array(
						'code' => 'attr_duplicated',
						'message' => sprintf(esc_attr__('The attribute %s is duplicated. You can select one at a time.', 'cslang'), '<b>' . $postData['errAttr'] . '</b>'),
					)
				);
			}
			$roles = (array) $postData['sync_role']; // array or string.
			$listIDs = (array) $postData['list_id'];
			unset($postData['sync_role']);
			unset($postData['list_id']);
			$usersData = 'EMAIL';
			foreach ($postData as $attrSibName => $attrWP) {
				$usersData .= ';' . $attrSibName;
			}
			// sync users to cirrusshield.
			// create body data like csv.
			// NAME;SURNAME;EMAIL\nName1;Surname1;example1@example.net\nName2;Surname2;example2@example.net.
			$contentData = '';
			foreach ($roles as $role) {
				$users = get_users(
					array(
						'role' => $role,
					)
				);
				if (empty($users)) {
					continue;
				}
				foreach ($users as $user) {
					$userId = $user->ID;
					$user_info = get_userdata($userId);
					$userData = $user_info->user_email;
					foreach ($postData as $attrSibName => $attrWP) {
						if ($attrWP == 'roles') {
							$userData .= ';' . implode(', ', $user_info->$attrWP);
						} else {
							$userData .= ';' . $user_info->$attrWP;
						}
					}
					$contentData .= "\n" . $userData;
				}
			}
			if ('' == $contentData) {
				wp_send_json(
					array(
						'code' => 'empty_users',
						'message' => __('There is not any user in the roles.', 'cslang'),
					)
				);
			}
			$usersData .= $contentData;
			$result = CS_API_Manager::sync_users($usersData, $listIDs);
			$currentUsers = count_users();
			if ('success' == $result['code']) {
				update_option('cssync_users', $currentUsers);
			}
			wp_send_json($result);
		}
		/** Logout process */
		function logout()
		{
			$setting = array();
			update_option(CS_Manager::MAIN_OPTION_NAME, $setting);
			$home_settings = array(
				'activate_email' => 'no',
				'activate_ma' => 'no',
			);
			update_option(CS_Manager::HOME_OPTION_NAME, $home_settings);
			// remove sync users option.
			delete_option('cssync_users');
			// remove all transients.
			CS_API_Manager::remove_transients();
			// remove all forms.
			CS_Forms::removeAllForms();
			CS_Forms_Lang::remove_all_trans();
			wp_safe_redirect(add_query_arg('page', self::PAGE_ID, admin_url('admin.php')));
			exit();
		}
	}
}
