<?php
/**
 * Admin page : dashboard
 *
 * @package CS_Page_Log
 */
if ( ! class_exists( 'CS_Page_Log' ) ) {
	/**
	 * Page class that handles backend page <i>dashboard ( for admin )</i> with form generation and processing
	 *
	 * @package CS_Page_Log
	 */
	class CS_Page_Log {
		/**
		 * Page slug
		 */
		const PAGE_ID = 'cspage_log';
		/**
		 * Page hook
		 *
		 * @var string
		 */
		protected $page_hook;
		/**
		 * Page tabs
		 *
		 * @var mixed
		 */
		protected $tabs;
		/**
		 * Constructs new page object and adds entry to WordPress admin menu
		 */
		function __construct() {
			$this->page_hook = add_submenu_page( CS_Page_Home::PAGE_ID, __( 'Login Logs', 'cslang' ), __( 'Login Logs', 'cslang' ), 'manage_options', self::PAGE_ID, array( &$this, 'generate' ) );
		    add_action( 'load-' . $this->page_hook, array( &$this, 'init' ) );
			add_action( 'admin_print_scripts-' . $this->page_hook, array( $this, 'enqueue_scripts' ) );
			add_action( 'admin_print_styles-' . $this->page_hook, array( $this, 'enqueue_styles' ) );
		}
		/**
		 * Init Process
		 */
		function Init() {
			add_action( 'admin_notices', array( 'CS_Manager', 'language_admin_notice' ) );
		}
		/**
		 * Enqueue scripts of plugin
		 */
		function enqueue_scripts() {
			wp_enqueue_script( 'cs-admin-js' );
			wp_enqueue_script( 'cs-bootstrap-js' );
			wp_localize_script(
				'cs-admin-js', 'ajax_csobject',
				array(
					'ajax_url' => admin_url( 'admin-ajax.php' ),
				)
			);
		}
		/**
		 * Enqueue style sheets of plugin
		 */
		function enqueue_styles() {
			wp_enqueue_style( 'cs-admin-css' );
			wp_enqueue_style( 'cs-bootstrap-css' );
			wp_enqueue_style( 'cs-fontawesome-css' );
			wp_enqueue_style( 'thickbox' );
		}
		/** Generate page script */
		function generate() {
			?>
			<div id="wrap1" class="box-border-box container-fluid">
				<div id="main-content"  class="row">
					<?php
					if ( CS_Manager::is_done_validation() ) {
						$this->generate_main_page();
					} else {
						$this->generate_welcome_page();
					}
					?>
				</div>
			</div>
			<style>
				#wpcontent {
					margin-left: 160px !important;
				}
				@media only screen and (max-width: 918px) {
					#wpcontent {
						margin-left: 40px !important;
					}
				}
			</style>
		<?php
		}
		/** Generate main page */
		function generate_main_page() { ?>
			<div id="wrap" class="wrap box-border-box container-fluid">
                <h1><img id="logo-img" src="<?php echo esc_url(CS_Manager::$plugin_url . '/img/logo.png'); ?>">
                    <a href="<?php echo esc_url(add_query_arg('page','cspage_form', admin_url('admin.php'))); ?>" class="button" style="margin-top: 6px; display: <?php echo esc_attr($return_btn); ?>;"><?php esc_attr_e('Back to Home', 'cslang'); ?></a>
                </h1>
                <div id="wrap-left" class="box-border-box col-md-9 ">
                    <!--<input type="hidden" class="cs-dateformat" value="<?php echo esc_attr($config['data']['date_format']); ?>">-->
                    <?php
                    if (CS_Manager::is_done_validation()) {
                        $this->generate_subscribe_page();
                    } else {
                        $this->generate_welcome_page();
                    }
                    ?>
                </div>
                <div id="wrap-right-side" class="box-border-box col-md-3">
                    <?php
                    CS_Page_Home::generate_side_bar();
                    ?>
                </div>
            </div>
		<?php }
     /** Generate subscribe list */
     function generate_subscribe_page() {  ?>
          <div id="main-content" class="cs-content">
                <div class="panel panel-default row small-content">
                   <div class="page-header"><strong><?php esc_attr_e('Logs of Sign-in/Activation in Cirrus Shield', 'cslang'); ?></strong></div>
                    <form method="post" class="cs-forms-wrapper" style="padding:20px;min-height: 500px;"> 
                     <table class="wp-list-table widefat fixed striped forms" border="1">
                     	<tr>
                     		<th>Username</th>
                     		<th>Sign-In Date Time</th>
                     		<th>Sign-Out Date Time</th>
                                <th>Status</th>
                     	</tr>
                       <?php
                       global $wpdb;
                       if (!$wpdb) {
                            $wpdb = new WPDB( 'root', '', 'worddumb', 'localhost');
                        } else {
                            global $wpdb; 
                        }
                        $result = $wpdb->get_results("SELECT * FROM `wp_cslog` WHERE 1 ORDER BY `logintime` DESC");
//                        $index = $wpdb->get_var( 'SELECT `id` FROM wp_cslog ORDER BY `id` DESC LIMIT 1 ;' ); 
//                        $wpdb->query( "UPDATE `wp_cslog` SET logouttime = '".time()."' WHERE id = ". $index.";" );
//						$subscribeList = CS_Model_Users::get_all_subscribe();
						foreach($result as $subList) {
//                          $formData           = CS_Forms::getForm($subList['frmid']);
//                          $subscribedDetails  = unserialize($subList['subscribedDetails']);
						  ?>
						   <tr>
						   	   <td>
						   	   	  <?php 
	                     	 	   	print_r($subList->username);
	                     	 	   ?>
	                     	 	</td>
                     	 	    <td>
                     	 	    	<?php 
                                        if($subList->logintime != ''){
                                            print_r(date('d-m-Y H:m:i', $subList->logintime));
                                        }
                     	 	    	?>
                     	 	    </td>
                     	 	    <td>
                     	 	    	<?php 
                                        if($subList->logouttime != ''){
                                            print_r(date('d-m-Y H:m:i', $subList->logouttime));
                                        }
                     	 	    	?>
                     	 	    </td>
                                    <td>
                                        <?php
                                            print_r($subList->status);
                                        ?>
                                    </td>
                     	   </tr>
						<?php } ?>
                     </table>
                 </form>
                </div>
            </div>
    <?php }
		/** Generate welcome page */
		function generate_welcome_page() {
			?>
			<img src="<?php echo esc_attr( CS_Manager::$plugin_url ) . '/img/background/lists.png'; ?>" style="width: 100%;">
		<?php
			CS_Page_Home::print_disable_popup();
		}
	}
}